#!/bin/bash

PATH=/sbin:/usr/sbin:$PATH

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

# ---------------------------------------------------------
# ipsets
ipset create black hash:ip timeout 600 > /dev/null 2>&1

# Allow all traffic within a set of networks
MYNETWORKS=iptables-autoapply-mynetworks
ipset flush $MYNETWORKS

ipset create $MYNETWORKS hash:net > /dev/null 2>&1
#ipset add $MYNETWORKS 62.50.100.2/27
ipset add $MYNETWORKS 10.0.0.0/8
ipset add $MYNETWORKS 192.168.0.0/16
ipset add $MYNETWORKS 172.16.0.0/12
ipset add $MYNETWORKS 127.0.0.0/8


# Default is to keep the existing policy untouched.
#iptables --policy INPUT DROP
#iptables --policy FORWARD DROP


# ---------------------------------------------------------
#
# - Moeglichkeit des sehr fruehen SRC-basierten Blockings.
# - fuer ad hoc Blocks, z.B. SYN-Defender usw.
#
iptables -t mangle -F PREROUTING
iptables -t mangle -A PREROUTING -m set --match-set black src -j DROP -m comment --comment "Dynamic source block"


# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

iptables -N DOCKER-USER > /dev/null 2>&1
iptables -F DOCKER-USER
iptables -I DOCKER-USER -j $IPT-FORWARD

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

iptables -A $IPT -m set --match-set $MYNETWORKS src,dst -j RETURN -m comment --comment "Private traffic"

iptables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN -m comment --comment "DNS"
iptables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN -m comment --comment "DNS"

# DEBUG: allow all ssh incoming
#iptables -I $IPT -p tcp --dport 22 -j RETURN

# Allow incoming DNS queries
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 53 -j RETURN"
#echo4 "-A INPUT -m state --state NEW -p udp --dport 53 -j RETURN"

# Allow incoming SMTP
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 25 -j RETURN"

# Typische Service-Ports f. Docker Services
iptables -A $IPT -m state --state NEW -p tcp --dport 80 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp --dport 443 -j RETURN
#iptables -A $IPT -m state --state NEW -p tcp --dport 9200 -j RETURN
#iptables -A $IPT -m state --state NEW -p tcp --dport 8080 -j RETURN

# https://superuser.com/questions/1471265/open-iptables-whithin-docker-compose-network-and-one-external-server
#iptables -A $IPT -m conntrack -p tcp --ctorigdst 212.9.161.112/32 --ctorigdstport 8022 -j RETURN


# Allow incoming NRPE -----------------------------------------
S=""
S="$S 62.50.111.16/28"      # monitor.lf.net
#S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 5666 -j RETURN -m comment --comment "NRPE monitoring"
done

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN


# Allow SSH from known sources ---------------------------
S=""
S="$S 212.9.190.0/24"       # LF.net Office
S="$S 212.9.190.18/32"      # zen.lf.net
S="$S 212.9.160.200/32"     # outcast.lf.net
S="$S 213.178.172.16/32"    # volz.eu
S="$S 212.9.183.0/25"       # LF.net VPN network
S="$S 212.9.190.49/32"      # hydra3.lf.net
S="$S 62.50.111.16/28"      # monitor.lf.net
S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 22 -j RETURN -m comment --comment "SSH from known sources"
done

# # Allow Bacula TCP/9102 from backup.lf.net --------------
# S=""
# S="$S 213.178.160.3/32"
# S="$S 213.178.162.248/32"
# S="$S 212.9.160.62/32"
# S="$S 212.9.160.106/32"
# S="$S 212.9.160.135/32"
# S="$S 212.9.161.106/32"
# for i in $S
# do
#   iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 9102 -j RETURN -m comment --comment "backup.lf.net"
# done


# Last rule must always be a DROP!
iptables -A $IPT -j DROP


# IPv6 =======================================================

ip6tables --policy INPUT DROP
ip6tables -F INPUT

ip6tables --policy FORWARD DROP
ip6tables -F FORWARD


# EOF
