#!/bin/bash

PATH=/sbin:$PATH

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY


# ---------------------------------------------------------
# ipsets


# -----

# TODO/FIXME: Directory f. cidr-lists sollte /usr/share/... sein, mit optionalem /etc/network/iptables-autoapply/cidr-lists als Vorrang.
# Ein temporaeres Set zum Befuellen:
for i in asia russia; do
  ipset create cidr-$i hash:net > /dev/null 2>&1
  ipset create tmp-cidr-$i hash:net maxelem 200000 > /dev/null 2>&1; ipset flush tmp-cidr-$i
  grep -v '^#' /etc/network/iptables-autoapply/cidr-lists/$i.list | while read a; do
    echo "add tmp-cidr-$i $a"
  done | ipset restore

  # Aktiven Block mit dem temporaeren tauschen u. dann temporaeren entfernen:
  ipset swap cidr-$i tmp-cidr-$i
  ipset destroy tmp-cidr-$i
done

set -x

# -----
ipset create black-src hash:net timeout 600 comment > /dev/null 2>&1

# Wird z.B. von RATELIMIT Chain befuellt.


# -----
ipset create black-dst hash:net timeout 600 comment > /dev/null 2>&1
ipset flush black-dst

# ipset add black-dst 212.9.186.40/32 --exist timeout 0 # DDoS 20200928 Caparol
# ipset add black-dst 212.9.186.49/32 --exist timeout 0 # DDoS 20201127, vserv.aki-stuttgart.de


# -----
ipset create black-sets-src list:set timeout 600 comment > /dev/null 2>&1
ipset flush black-sets-src
ipset add black-sets-src black-src --exist timeout 0 # blacklistet source IP, *immer* blocken

# ipset add black-sets-src cidr-russia --exist timeout 0    # NOTFALL: Russia blocken
# ipset add black-sets-src cidr-asia --exist timeout 0      # NOTFALL: Asien blocken (inkl. Russia etc.)


# -----
ipset create white-src hash:net timeout 0 comment > /dev/null 2>&1

ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

ipset add tmp 62.50.111.0/24 comment "monitor.lf.net"
#ipset add tmp xx.xx.xx.0/24 comment "Netze fuer <customer> Proxmox"

# LF.net Support Netze, aus ehemaliger MGMTIN chain
ipset add tmp 212.9.190.0/24 comment "LF.net R27 Office"
ipset add tmp 212.9.160.128/25
ipset add tmp 212.9.160.64/27
ipset add tmp 62.50.111.16/28
ipset add tmp 212.9.160.15/32
ipset add tmp 213.178.172.0/26

# IP-Adressen und Netze von Bitzer und Dienstleistern
ipset add tmp 160.44.229.82 comment "Bitzer Webzugriff"
ipset add tmp 160.44.229.68 comment "Bitzer SSH-Zugriff"
ipset add tmp 62.50.124.44 comment "OpenVPN m.herter@logic-joe.com"
ipset add tmp 62.50.124.45 comment "OpenVPN s.kiera@logic-joe.com"
ipset add tmp 62.50.124.46 comment "OpenVPN d.knoblich@logic-joe.com"
ipset add tmp 62.50.124.47 comment "OpenVPN t.widmayer@logic-joe.com"
ipset add tmp 62.50.124.50 comment "OpenVPN n.ostojic@logic-joe.com"
ipset add tmp 62.50.124.59 comment "OpenVPN t.godzisz@logic-joe.com"
ipset add tmp 62.50.124.61 comment "OpenVPN s.kraus@logic-joe.com"

ipset add tmp 212.224.115.131 comment "AWA-Amaturenwerk"

ipset swap tmp white-src
ipset destroy tmp


#  -------------------------------------------
# Liste der RevProxy-Adressen

# TODO: verlegen in Debian Paket, also /usr/share/iptables-autoapply/cidr-lists
ipset create revproxy-src hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

ipset add tmp 62.50.112.200 comment "revproxy00.lf.net"
ipset add tmp 62.50.112.201 comment "revproxy01.lf.net"
ipset add tmp 62.50.112.202 comment "revproxy02.lf.net"
ipset add tmp 62.50.112.203 comment "revproxy03.lf.net"
ipset add tmp 18.192.50.171 comment "revproxy04.aws.lf.net"
ipset add tmp 3.123.75.106 comment "revproxy05.aws.lf.net"

ipset swap tmp revproxy-src
ipset destroy tmp

# Kunden-IPs, die auf das Proxmox Cluster per SSH, 8006 etc. zugreifen duerfen
# ipset create customer-proxmox-access hash:net timeout 0 comment > /dev/null 2>&1

# Menge der Proxmox-Rechner im Cluster
# TODO: diese in z.B. /etc/network/iptables.d/siriusnet.sh pflegen.
# ipset create proxmox-networks hash:net timeout 0 comment > /dev/null 2>&1

# Liste der Webserver die von ANY per HTTP / HTTPS erreicht werden duerfen
ipset create set-webserver hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

ipset add tmp 212.9.185.166 comment web01.bitzer.de
ipset add tmp 212.9.185.170 comment www.bitzer.de
ipset add tmp 212.9.185.171 comment www.the-schaufler-foundation.de
ipset add tmp 212.9.185.173 comment www.schauwerk-sindelfingen.de
ipset add tmp 212.9.185.174 comment www.awa-armaturenwerk.de
ipset add tmp 212.9.185.176 comment vserv07.bitzer.de 
ipset add tmp 212.9.185.177 comment vserv08.bitzer.de
ipset add tmp 212.9.185.178 comment vserv09.bitzer.de
ipset add tmp 212.9.185.179 comment vserv10.bitzer.de
ipset add tmp 212.9.185.180 comment vserv11.bitzer.de
ipset add tmp 212.9.185.181 comment typo3.bitzer.de
ipset add tmp 212.9.185.185 comment vserv13.bitzer.de
#ipset add tmp 212.9.185.187 comment www.intelligent-compressors.com
#ipset add tmp 212.9.185.188 comment www.intelligente-verdichter.de
ipset add tmp 212.9.185.189 comment vserv14.bitzer.de
#ipset add tmp 212.9.185.190 comment www.bitzeravp.com

ipset swap tmp set-webserver
ipset destroy tmp

# Liste der Webserver, die nur ueber Reverse-Proxy erreichbar sind
ipset create revproxy-webserver hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

ipset add tmp 212.9.185.166 comment web01.bitzer.de
ipset add tmp 212.9.185.170 comment www.bitzer.de
ipset add tmp 212.9.185.171 comment www.the-schaufler-foundation.de
ipset add tmp 212.9.185.173 comment www.schauwerk-sindelfingen.de
ipset add tmp 212.9.185.174 comment www.awa-armaturenwerk.de
ipset add tmp 212.9.185.190 comment www.bitzeravp.com

ipset swap tmp revproxy-webserver
ipset destroy tmp

# ----------------------------
# Liste der Mailserver die von ANY per SMPT / POP / IMAP erreicht werden duerfen
ipset create set-mailserver hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

ipset add tmp 212.9.185.175 comment newsletter.bitzer.de

ipset swap tmp set-mailserver
ipset destroy tmp

# ----------------------------
# Liste der DMZ-Netze die Zugang ins Internet bekommen
ipset create set-dmz hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

ipset add tmp 212.9.185.160/27 comment "DMZ hinter Firewall"

ipset swap tmp set-dmz
ipset destroy tmp



# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT


# Hook our iptables-autoapply rules to INPUT/OUTPUT/FORWARD ---------------------------------
## iptables --policy INPUT ACCEPT
## iptables --policy OUTPUT ACCEPT
## iptables --policy FORWARD ACCEPT
## 
## iptables -t mangle -F PREROUTING
## iptables -t mangle -F POSTROUTING
## 
## iptables -F INPUT
## iptables -F OUTPUT
## iptables -F INPUT
## 
## 

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1
# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1
iptables -I FORWARD -j $IPT-FORWARD

# For safety
iptables -I INPUT -s 212.9.190.0/24 -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "SSH from known sources"
#iptables -I $IPT -s 212.9.190.0/24 -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "SSH from known sources"

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN


# TODO/FIXME: DNS global offen ist problematisch.
#iptables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN -m comment --comment "DNS"
#iptables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN -m comment --comment "DNS"

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN

# auf loopback alles erlauben
iptables -A $IPT -i lo -j RETURN -m comment --comment "Allow loopback traffic"


## # ep, Mon Apr 12 10:58:24 CEST 2021
## # LFN21461028
## # RPC fuer alle filtern
## iptables -A INPUT -p tcp --dport 111 -j REJECT
## iptables -A INPUT -p udp --dport 111 -j REJECT

# LOGGING
#-N LOGGING
#-A LOGGING -m limit --limit 5/sec -j LOG --log-prefix "SYN-Defender-Dropped: " --log-level 4

iptables -A $IPT -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
iptables -A $IPT -m set --match-set black-dst dst -j DROP -m comment --comment "Dynamic dst block"
iptables -A $IPT -m set --match-set white-src src -j RETURN -m comment --comment "Accept from LF white-src"


# Proxmox interoperability ---------------------------------------------------
#
# https://pve.proxmox.com/wiki/Firewall
#
#iptables -A $IPT -p tcp --dport 8006 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox API"
#iptables -A $IPT -p tcp --dport 5900:5999 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox VNC"
#iptables -A $IPT -p tcp --dport 22 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox SSH"
#iptables -A $IPT -p tcp --dport 3128 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox SPICE"
#iptables -A $IPT -p udp --dport 5404:5405 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox corosync"
#iptables -A $IPT -p tcp --dport 60000:60050 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox livemig"


# Customer access
iptables -I $IPT -m state --state NEW -p tcp --dport 22 -d 212.9.185.168 -j ACCEPT -m comment --comment "n00.c01.bitzer.de"
#iptables -I $IPT -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "ACHTUNG - muss deaktiviert werden"
iptables -I $IPT -m state --state NEW -p tcp --dport 8983 -j ACCEPT -m comment --comment "ACHTUNG - muss deaktiviert werden"

# Zugriff auf win01, fuer bitzer software
#iptables -I $IPT -m state --state NEW -p tcp -d 212.9.175.110 -j ACCEPT -m comment --comment "ACHTUNG - muss deaktiviert werden"

#iptables -A $IPT -p tcp --dport 22 -m set --match-set customer-proxmox-access src -j RETURN
#iptables -A $IPT -p tcp --dport 8006 -m set --match-set customer-proxmox-access src -j RETURN

iptables -A $IPT -m set --match-set set-dmz src -j RETURN -m comment --comment "Allow outgoing from DMZ"

iptables -A $IPT -p tcp --dport  80 -m set --match-set set-webserver dst -j RETURN -m comment --comment "Allow HTTP"
iptables -A $IPT -p tcp --dport 443 -m set --match-set set-webserver dst -j RETURN -m comment --comment "Allow HTTP"

#iptables -N LFNET_REVPROXY_TO_WEBSERVER > /dev/null 2>&1
#iptables -F LFNET_REVPROXY_TO_WEBSERVER
#iptables -A LFNET_REVPROXY_TO_WEBSERVER -m set --match-set revproxy-src  src -j RETURN -m comment --comment "No rate-limiting for LF white-src"

iptables -A $IPT -p tcp --dport  80 -m set --match-set revproxy-src src -m set --match-set revproxy-webserver dst -j RETURN -m comment --comment "Allow HTTP"
iptables -A $IPT -p tcp --dport 443 -m set --match-set revproxy-src src -m set --match-set revproxy-webserver dst -j RETURN -m comment --comment "Allow HTTP"

# k8s Service Netz
iptables -A $IPT -p tcp -d 62.50.114.128/28 -j RETURN

iptables -A $IPT -p tcp -s 212.9.160.4 --dport 25 -m set --match-set set-mailserver dst -j RETURN -m comment --comment "Allow SMTP"

# LFN23484007
# newsletter.bitzer.de:8080 muss wieder von aussen erreichbar sein

iptables -A $IPT -p tcp -d 212.9.185.175 --dport 8080 -j RETURN -m comment --comment "Allow access to Tomcat for newsletter.bitzer.de"

#iptables -A $IPT -p tcp --dport 143 -m set --match-set set-mailserver dst -j RETURN -m comment --comment "Allow IMAP"

## # wir blocken nur syn-flag, damit eine schon eingeloggte SSH-Verbindung mit der selben IP nicht geblockt wird
## # 60 Sekunden Wartezeit/Block sollte ausreichen, da die Zeit sich dynamisch verlaengert
## # Die IP-Zugriffe werden in "/proc/net/xt_recent/BLOCK_SSH" aktuallisiert,
## # per default werden die letzten 100 IP von recent aufgelistet
## ipset destroy block_ssh
## ipset create block_ssh hash:ip timeout 60
## iptables -A INPUT -p tcp -m conntrack --ctstate ESTABLISHED,RELATED --sport 1024: --dport 22 -j ACCEPT
## iptables -A INPUT -p tcp -m set --match-set block_ssh src -j REJECT -m comment --comment "SSH-Sperre nach 3 Versuchen"
## iptables -A INPUT -p tcp -m conntrack --ctstate NEW --dport 22 -m recent --name BLOCK_SSH --set
## iptables -A INPUT -p tcp -m conntrack --ctstate NEW --dport 22 -m recent --update --seconds 60 --hitcount 3 --rttl --name BLOCK_SSH -j SET --add-set block_ssh src
## iptables -A INPUT -p tcp -m conntrack --ctstate NEW --sport 1024: --dport 22 -j ACCEPT

#iptables -A $IPT -m set --match-set proxmox-networks src -j LOG --log-prefix "PROXMOX-NETWORKS blocked: "

iptables -A $IPT -j LOG --log-prefix "iptables-autoapply "

# Last rule must always be a DROP or REJECT!
iptables -A $IPT -j DROP
