#!/bin/bash

set -Eeu -o pipefail

function trap_error {
  # trap_cleanup # in case we want to cleanup something
  echo "$0: failed in line $*" >&2
  exit 2
}

trap 'trap_error $LINENO' ERR

PATH=/sbin:$PATH

ipset destroy tmp > /dev/null 2>&1 || true

# ---------------------------------------------------------
# ipsets


# -----

# Ein temporaeres Set zum Befuellen:
for i in asia russia; do
  ipset create cidr-$i hash:net > /dev/null 2>&1 || true
  ipset create tmp-cidr-$i hash:net maxelem 200000 # > /dev/null 2>&1; ipset flush tmp-cidr-$i
  grep -v '^#' /etc/network/iptables-autoapply/cidr-lists/$i.list | while read a; do
    echo "add tmp-cidr-$i $a"
  done | ipset restore

  # Aktiven Block mit dem temporaeren tauschen u. dann temporaeren entfernen:
  ipset swap cidr-$i tmp-cidr-$i
  ipset destroy tmp-cidr-$i
done


# -----
ipset create black-src hash:net timeout 600 > /dev/null 2>&1 || true

# Wird z.B. von RATELIMIT Chain befuellt.


# -----
ipset create black-dst hash:net timeout 600 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 600

ipset add tmp 212.9.186.40/32 --exist timeout 0 # DDoS 20200928 Caparol
# ipset add tmp 212.9.186.49/32 --exist timeout 0 # DDoS 20201127, vserv.aki-stuttgart.de

ipset swap black-dst tmp
ipset destroy tmp

# -----
ipset create black-sets-src list:set timeout 600 > /dev/null 2>&1 || true
ipset create tmp list:set timeout 600

ipset add tmp black-src --exist timeout 0 # blacklistet source IP, *immer* blocken

# ipset add tmp cidr-russia --exist timeout 0 # NOTFALL: Russia
# blocken ipset add tmp cidr-asia --exist timeout 0 # NOTFALL: Asien
# blocken (inkl. Russia etc.)

ipset swap black-sets-src tmp
ipset destroy tmp


# -----
ipset create white-src hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0

# Comments funktionieren nicht (Stand 10/2020 mit Kernel 3.16.0).
ipset add tmp 62.50.112.200 	# comment "revproxy00.lf.net"
ipset add tmp 62.50.112.201 	# comment "revproxy01.lf.net"
ipset add tmp 62.50.112.202 	# comment "revproxy02.lf.net"
ipset add tmp 62.50.112.203 	# comment "revproxy03.lf.net"
ipset add tmp 18.192.50.171 	# comment "revproxy04.aws.lf.net"
ipset add tmp 3.123.75.106 	# comment "revproxy05.aws.lf.net"

ipset add tmp 62.50.111.0/24  # comment "monitor.lf.net"

ipset swap white-src tmp
ipset destroy tmp

# VVS-IPs fuer die ein rate-limiting aktiviert werden soll:
ipset create vvs-dst hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0
ipset add tmp 213.178.170.102   # www.vvs.de
ipset swap vvs-dst tmp
ipset destroy tmp

# Revproxies
ipset create lfnet-revproxies hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0
ipset add tmp 62.50.112.200 	# comment "revproxy00.lf.net"
ipset add tmp 62.50.112.201 	# comment "revproxy01.lf.net"
ipset add tmp 62.50.112.202 	# comment "revproxy02.lf.net"
ipset add tmp 62.50.112.203 	# comment "revproxy03.lf.net"
ipset add tmp 18.192.50.171 	# comment "revproxy04.aws.lf.net"
ipset add tmp 3.123.75.106 	# comment "revproxy05.aws.lf.net"

ipset swap lfnet-revproxies tmp
ipset destroy tmp

# Wed Apr 23 12:05:05 CEST 2025 -rodney@LF.net
# - LFNET Proxmox Cluster
ipset create lfnet-proxmox hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0

# LFNET proxmox cluster
ipset add tmp 212.9.176.64/26    # comment "p02nXX und vzhosts, VLAN96"
ipset add tmp 62.50.111.192/26   # comment "p03nXX VLAN97"
ipset add tmp 62.50.113.0/26     # comment "p04nXX, p05nXX: VLAN93"
ipset add tmp 213.178.162.192    # comment "vzhostXX - TODO: remove"
ipset add tmp 62.50.113.64/27    # comment "p06nXX VLAN134"

ipset swap lfnet-proxmox tmp
ipset destroy tmp


# ---------------------------------------------------------
# Interface-Listen

# Peers
IFLIST_PEERS=""
IFLIST_PEERS="$IFLIST_PEERS eth5.107"     # core01: Interscholz/Nepustil
IFLIST_PEERS="$IFLIST_PEERS bond0.20"     # core01: QSC
IFLIST_PEERS="$IFLIST_PEERS eth8.373"     # core02: EU Networks

# TODO: Akamai SiteShield Aktualisierung? Als Feature anbieten?
# - Siteshield Adressen in ein ipset
# - Endkunden, die Sperrung wuenschen, in ein ipset


# -------------------------------------------------------------------------------------
# filter

# Wed Apr 23 12:40:26 CEST 2025 -rodney@LF.net
# - TODO: ans Ende verlegen.
#   o INPUT, OUTPUT und FORWARD sollten sehr kurz sein.
#   o die Befuellung sollte erst passieren, wenn alle anderen
#     Commands fehlerfrei durchgelaufen sind (vgl. oben, set -Eeu -o pipefail).
#

iptables --policy INPUT ACCEPT
iptables --policy OUTPUT ACCEPT
iptables --policy FORWARD ACCEPT

iptables -F INPUT
iptables -F OUTPUT
iptables -F FORWARD

iptables -t mangle -F PREROUTING
iptables -t mangle -F POSTROUTING

# *filter
# :INPUT ACCEPT [0:0]
# :OUTPUT ACCEPT [0:0]
# :FORWARD ACCEPT [0:0]

# auf loopback alles erlauben
iptables -A INPUT -i lo -j ACCEPT

# LOGGING
#-N LOGGING
#-A LOGGING -m limit --limit 5/sec -j LOG --log-prefix "SYN-Defender-Dropped: " --log-level 4

# .eof
#
# cat6 <<.eof
# # ip6tables Header ---------------------------------------
# *filter
# :INPUT ACCEPT
# .eof
#
# cat4 <<.eof

# Tue Sep 22 23:55:43 CEST 2020 -Rodney
# - caparol, DDoS
#iptables -A INPUT -d 212.9.186.40 -j DROP -m comment --comment "Caparol DDoS 202009"

iptables -A INPUT -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
iptables -A INPUT -m set --match-set black-dst dst -j DROP -m comment --comment "Dynamic dst block"

# TODO: tut noch nicht, tcpdump sagt "no buffer space available"
#iptables -A FORWARD -m tcp --dport 80 -j NFLOG --nflog-group 100 --nflog-threshold 10 -m comment --comment "tcpdump -ni nflog:100 # traffic nach drop rules"


# --------------------------------------------------------------------------
# SYN-Flood-Defender

# Folgende Rechner sollen *nicht* in die Blacklist laufen.
# FIXME: sollte nicht einfach "-j ACCEPT" machen, weil die anderen Rules dann nicht durchlaufen werden.
#iptables -A FORWARD -s 62.50.111.0/24 -j ACCEPT -m comment --comment "Allow from monitor.lf.net"

# IPs, die in 30 Sekunden-Messintervallen > 500 SYNs/s schicken, verwerfen
#
#-A FORWARD -p tcp -m tcp --tcp-flags FIN,SYN,RST,ACK SYN -m hashlimit --hashlimit-above 800/sec --hashlimit-burst 2000 --hashlimit-mode srcip --hashlimit-name synflood --hashlimit-htable-size 4194304 --hashlimit-htable-expire 120000 -j DROP
#-A FORWARD -p tcp -m tcp --tcp-flags FIN,SYN,RST,ACK SYN -m hashlimit --hashlimit-above 30/sec --hashlimit-burst 35 --hashlimit-mode srcip --hashlimit-name synflood \
#           --hashlimit-htable-size 4194304 --hashlimit-htable-max 73554432 --hashlimit-htable-expire 120000 \
#           -j SET --add-set black-src src --timeout 60 --exist
#
#            --hashlimit-srcmask 24 \
#

iptables -N RATELIMIT > /dev/null 2>&1 || true
iptables -F RATELIMIT

iptables -A RATELIMIT -m set --match-set white-src src -j RETURN -m comment --comment "No rate-limiting for LF white-src"

# allgemeines Rate-Limiting:
#iptables -A RATELIMIT -p tcp -m tcp --tcp-flags FIN,SYN,RST,ACK SYN -m hashlimit --hashlimit-above 250/sec \
#           --hashlimit-burst 500 --hashlimit-mode srcip --hashlimit-name synflood_interscholz \
#           --hashlimit-htable-size 8194304 --hashlimit-htable-max 73554432 --hashlimit-htable-expire 15000 \
#           -j SET --add-set black-src src --timeout 120 --exist

# VVS rate-limiting rule
#iptables -A RATELIMIT \
#	 -p tcp -m set --match-set vvs-dst dst \
#	 -m hashlimit --hashlimit-above 250/sec \
#	 --hashlimit-burst 500 --hashlimit-mode srcip --hashlimit-name ddos_vvs \
#	 --hashlimit-htable-size 8194304 --hashlimit-htable-max 73554432 --hashlimit-htable-expire 15000 \
#	 -j SET --add-set black-src src --timeout 120 --exist

# DEFCON, false aendern in true fuer Aktivierung
if false; then
  for IF in $IFLIST_PEERS; do
    iptables -A FORWARD -i $IF -j RATELIMIT -m comment --comment "DEFCON: rate limiting for if $IF"
  done
fi


# ---------------------------------------------------------
# Mon Sep 28 16:56:49 CEST 2020 -Rodney
# - Rules aus DDoS 20200928

#
# Sat Nov 28 01:35:26 CET 2020 -rodney@LF.net
# - bisher:
#   iptables -t mangle -A PREROUTING -i $IF -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
#

for IF in $IFLIST_PEERS; do
  iptables -A FORWARD -i $IF -m set --match-set white-src src -j ACCEPT -m comment --comment "Accept from LF white-src"

  # Dynamic source blocking, z.B. f. SYN Flood Defender
  iptables -A FORWARD -i $IF -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
  iptables -A FORWARD -i $IF -m set --match-set black-dst dst -j DROP -m comment --comment "Dynamic dst block"
done


# FIXME/TODO:
#iptables -t mangle -A PREROUTING -j NFLOG --nflog-group 100 --nflog-threshold 10 -m comment --comment "tcpdump -ni nflog:100 # traffic nach drop rules"


# ---------------------------------------------------------
# erlaube folgenden Management Traffic zu diesem Router
# :MGMTIN - [0:0]

iptables -N MGMTIN > /dev/null 2>&1 || true
iptables -F MGMTIN
iptables -A INPUT -p tcp --dport 22 -j MGMTIN

# Mgmt protection rules - macht fail2ban ueberfluessig
iptables -A MGMTIN -s 212.9.190.0/24 -j ACCEPT
iptables -A MGMTIN -s 212.9.160.128/25 -j ACCEPT
iptables -A MGMTIN -s 212.9.160.64/27 -j ACCEPT
iptables -A MGMTIN -s 62.50.111.16/28 -j ACCEPT -m comment --comment "monitor.lf.net Netz"
iptables -A MGMTIN -s 212.9.160.15 -j ACCEPT
iptables -A MGMTIN -s 213.178.172.0/26 -j ACCEPT

# pbx-sip01.lf.net als Jump-Host fuer out-of-band-Zugang:
iptables -A MGMTIN -s 212.9.176.122/32 -j ACCEPT

# alles was in MGMTIN bisher nicht erlaubt wurde, wird verboten
iptables -A MGMTIN -j REJECT


# # erlaube folgende BGP Sessions zu diesem Router
# :BGPIN - [0:0]

iptables -N BGPIN > /dev/null 2>&1 || true
iptables -F BGPIN

iptables -A INPUT -p tcp --dport 179 -j BGPIN
iptables -A INPUT -p tcp --sport 179 -j BGPIN

iptables -A INPUT -d 213.155.141.153 -p icmp --icmp-type echo-request -j DROP -m comment --comment "bgp adr. soll kein echo liefern"


# 212.9.160.75 AS12374 core01/02.lf.net
iptables -A BGPIN -s 212.9.160.75 -j ACCEPT -m comment --comment "AS12374 core01/02.lf.net"
iptables -A BGPIN -s 212.9.160.74 -j ACCEPT -m comment --comment "AS12374 core01/02.lf.net"

# 85.236.201.149 AS33843 Interscholz
iptables -A BGPIN -s 85.236.201.149 -j ACCEPT -m comment --comment "AS33843 Interscholz/Nepustil"
iptables -A BGPIN -s 82.98.224.65/32 -j ACCEPT -m comment --comment "AS33843 Interscholz/Nepustil"

# 212.202.214.77 AS20676 QSC AG
iptables -A BGPIN -s 212.202.214.77 -j ACCEPT -m comment --comment "AS20676 QSC AG"

# S-IX BGP
iptables -A BGPIN -s 193.138.31.0/24 -j ACCEPT -m comment --comment "S-IX BGP"

# ARELION, 07/2024
iptables -A BGPIN -s 213.155.141.152/32 -j ACCEPT -m comment --comment "AS1299 Arelion, 07/2024"

# Inter.Link, 07/2024
iptables -A BGPIN -s 45.153.82.58/32 -j ACCEPT -m comment --comment "AS5405 Inter.Link, 07/2024"

#iptables -A BGPIN -j REJECT
iptables -A BGPIN -j DROP -m comment --comment "Avoid icmp unreachable spam"


# --------------------------------
# Erlaube eingehenden und ausgehenden OSPF Traffic

# - Auf dem Core Backbone
iptables -A INPUT -i bond0.100 -s 212.9.160.64/27 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.100 -d 212.9.160.64/27 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.100 -d 224.0.0.5/32 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.100 -d 224.0.0.6/32 -p 89 -j ACCEPT
# - dem Backup-Pfad zu sw1-k25
# -A INPUT -i bond2.207 -s 213.178.161.96/28 -p 89 -j ACCEPT
# -A OUTPUT -o bond2.207 -d 213.178.161.96/28 -p 89 -j ACCEPT
#-A OUTPUT -o bond2.207 -d 224.0.0.5/32 -p 89 -j ACCEPT
#-A OUTPUT -o bond2.207 -d 224.0.0.6/32 -p 89 -j ACCEPT
# - dem Access-Netz
iptables -A INPUT -i bond0.110 -s 212.9.160.0/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.110 -d 212.9.160.0/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.110 -d 224.0.0.5/32 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.110 -d 224.0.0.6/32 -p 89 -j ACCEPT
# - Webnetz, VZ-Hosts
iptables -A INPUT -i bond0.113 -s 213.178.162.192/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.113 -d 213.178.162.192/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.113 -d 224.0.0.5/32 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.113 -d 224.0.0.6/32 -p 89 -j ACCEPT
# - VZ-Hosts neues Netz
iptables -A INPUT -i bond0.96 -s 212.9.176.64/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.96 -d 212.9.176.64/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.96 -d 224.0.0.5/32 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.96 -d 224.0.0.6/32 -p 89 -j ACCEPT

iptables -A INPUT -i bond0.93 -s 62.50.113.0/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.93 -d 62.50.113.0/26 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.93 -d 224.0.0.5/32 -p 89 -j ACCEPT
iptables -A OUTPUT -o bond0.93 -d 224.0.0.6/32 -p 89 -j ACCEPT

# verwerfe alle anderen OSPF Pakete
iptables -A INPUT -p 89 -j REJECT
iptables -A OUTPUT -p 89 -j REJECT

# erlaube Bacula Backup Traffic
# :BACKUPIN - [0:0]

iptables -N BACKUPIN > /dev/null 2>&1 || true
iptables -F BACKUPIN

iptables -A INPUT -p tcp --dport 9102 -j BACKUPIN
iptables -A BACKUPIN -s 213.178.160.3 -j ACCEPT
iptables -A BACKUPIN -s 212.9.160.62 -j ACCEPT
iptables -A BACKUPIN -s 212.9.160.106 -j ACCEPT
iptables -A BACKUPIN -s 212.9.160.135 -j ACCEPT
iptables -A BACKUPIN -s 212.9.161.106 -j ACCEPT
iptables -A BACKUPIN -s 212.9.190.113 -j ACCEPT
# filtere sonstigen Backup Traffic
iptables -A BACKUPIN -p tcp --dport 9102 -j REJECT

# th, Fri Aug 12 17:45:17 CEST 2011
# :BACKUPFOR - [0:0]

iptables -N BACKUPFOR > /dev/null 2>&1 || true
iptables -F BACKUPFOR

# bacula-fd ins Access-Netz, Webnetz, VZ-Host-Netz, Ceph-Netz, VVS, Sirius (110, 113, 96, 93, 301, 302) erfassen
iptables -A FORWARD -o bond0.96 -p tcp --dport 9102 -j BACKUPFOR
iptables -A FORWARD -o bond0.110 -p tcp --dport 9102 -j BACKUPFOR
iptables -A FORWARD -o bond0.113 -p tcp --dport 9102 -j BACKUPFOR
iptables -A FORWARD -o bond0.301 -p tcp --dport 9102 -j BACKUPFOR
iptables -A FORWARD -o bond0.302 -p tcp --dport 9102 -j BACKUPFOR

iptables -A BACKUPFOR -s 213.178.160.3 -j ACCEPT
iptables -A BACKUPFOR -s 212.9.160.62 -j ACCEPT
iptables -A BACKUPFOR -s 212.9.160.106 -j ACCEPT
iptables -A BACKUPFOR -s 212.9.160.135 -j ACCEPT
iptables -A BACKUPFOR -s 212.9.161.106 -j ACCEPT
iptables -A BACKUPFOR -s 212.9.190.113 -j ACCEPT
# filtere sonstigen Backup Traffic
iptables -A BACKUPFOR -p tcp --dport 9102 -j REJECT

# th, Tue Aug 16 15:09:59 CEST 2011
# :ACCESSFOR - [0:0]

iptables -N ACCESSFOR > /dev/null 2>&1 || true
iptables -F ACCESSFOR

# SSH Traffic via bond0.110
#iptables -A FORWARD -o bond0.110 -d 212.9.160.0/26 -p tcp --dport 22 -j ACCESSFOR
iptables -A FORWARD -d 62.50.111.0/28 -p tcp --dport 22 -j ACCESSFOR
iptables -A FORWARD -o bond0.110 -d 62.50.111.16/28 -p tcp --dport 22 -j ACCESSFOR

# SSH ins Access Netz fuer die Office LANs
iptables -A ACCESSFOR -s 212.9.190.0/24 -j ACCEPT
iptables -A ACCESSFOR -s 212.9.160.128/25 -j ACCEPT

# ncp.lf.net, vpn configs copy
iptables -A ACCESSFOR -s 212.9.191.135/32 -j ACCEPT

# monitor darf auch rein
iptables -A ACCESSFOR -s 62.50.111.16/28 -j ACCEPT

# SSH ins Access Netz fuer mail.netic.de (aktuell deaktiviert)
# -A ACCESSFOR -s 212.9.160.11 -j ACCEPT
# -A ACCESSFOR -s 212.9.160.12 -j ACCEPT

# fh, Fri Feb 10 10:26:16 CET 2012
# erlaube rsync via ssh von dck03.dev.lf.net und dck01.dev.lf.net auf mail.lf.net
iptables -A ACCESSFOR -p tcp -s 212.9.161.108 -d 212.9.160.2  --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 212.9.161.84  -d 212.9.160.2  --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 62.50.111.197 -d 212.9.160.2  --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 212.9.160.29  -d 212.9.160.2  --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 212.9.161.108 -d 212.9.160.17 --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 212.9.161.84  -d 212.9.160.17 --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 62.50.111.197 -d 212.9.160.17 --dport 22 -j ACCEPT
iptables -A ACCESSFOR -p tcp -s 212.9.160.29  -d 212.9.160.17 --dport 22 -j ACCEPT
# dck01.dev.lf.net auf dck01.netic.de
iptables -A ACCESSFOR -p tcp -s 212.9.161.84  -d 212.9.160.20 --dport 22 -j ACCEPT

# filtere sonstigen Traffic in dieser Table
iptables -A ACCESSFOR -j REJECT


#
# Globale Filter
# --------------
#

# LFN27278802 mail.netic.de bis auf essentielle Dienste (Mail, Web)
# abdichten wg. fortgesetztem Missbrauch
# LF office darf
## iptables -A FORWARD -i bond0.110 -s 212.9.190.0/24 -d 212.9.160.11 -j ACCEPT
iptables -A FORWARD -i bond0.110 -s 212.9.190.0/24 -d 212.9.160.12 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -d 212.9.190.0/24 -s 212.9.160.11 -p tcp --sport 22 -j ACCEPT

# Monitoring darf auch
## iptables -A FORWARD -i bond0.110 -s 62.50.111.16/28 -d 212.9.160.11 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -d 62.50.111.16/28 -s 212.9.160.11 -j ACCEPT
iptables -A FORWARD -i bond0.110 -s 62.50.111.16/28 -d 212.9.160.12 -j ACCEPT
iptables -A FORWARD -i bond0.110 -d 62.50.111.16/28 -s 212.9.160.12 -j ACCEPT

## # mail.netic.de
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport  25 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport 587 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport 465 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport 995 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport 110 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport  80 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --sport 443 -j ACCEPT

# www.netic.de
iptables -A FORWARD -i bond0.110 -s 212.9.160.12 -p tcp --sport  80 -j ACCEPT
iptables -A FORWARD -i bond0.110 -s 212.9.160.12 -p tcp --sport 443 -j ACCEPT

# www.lf.net
iptables -A FORWARD -m set --match-set lfnet-revproxies src -d 212.9.160.24 -p tcp --dport 80 -j ACCEPT -m comment --comment "www.lf.net"
iptables -A FORWARD -m set --match-set lfnet-revproxies src -d 212.9.160.24 -p tcp --dport 443 -j ACCEPT -m comment --comment "www.lf.net"
iptables -A FORWARD -s 212.9.160.24 -p tcp --dport 43 -j ACCEPT -m comment --comment "www.lf.net whois"
iptables -A FORWARD -d 212.9.160.24 -p tcp --sport 43 -j ACCEPT -m comment --comment "www.lf.net whois"
iptables -A FORWARD -s 212.9.160.24 -p udp --dport 53 -j ACCEPT -m comment --comment "www.lf.net dns"
iptables -A FORWARD -s 62.50.111.1  -p tcp --sport 53 -j ACCEPT -m comment --comment "www.lf.net dns"
# support/tools/traceroute.php und ping.php
iptables -A FORWARD -d 212.9.160.24 -p icmp --icmp-type echo-reply -j ACCEPT -m comment --comment "www.lf.net tools/traceroute"
iptables -A FORWARD -s 212.9.160.24 -p icmp --icmp-type echo-request -j ACCEPT -m comment --comment "www.lf.net tools/traceroute"
iptables -A FORWARD -d 212.9.160.24 -p icmp --icmp-type time-exceeded -j ACCEPT -m comment --comment "www.lf.net tools/traceroute"
iptables -A FORWARD -d 212.9.160.24 -p icmp --icmp-type destination-unreachable -j ACCEPT -m comment --comment "www.lf.net tools/traceroute"
iptables -A FORWARD -s 212.9.160.24 -p udp --dport 33434:33534 -j ACCEPT -m comment --comment "www.lf.net tools/traceroute"
#
iptables -A FORWARD -d 212.9.160.24 -j REJECT -m comment --comment "www.lf.net"

# Jeder darf rein und raus pingen
## iptables -A FORWARD -i bond0.110 -d 212.9.160.11 -p icmp -j ACCEPT
iptables -A FORWARD -i bond0.110 -d 212.9.160.12 -p icmp -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p icmp -j ACCEPT
iptables -A FORWARD -i bond0.110 -s 212.9.160.12 -p icmp -j ACCEPT

# outgoing services
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --dport 53 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p udp --dport 53 -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --dport ntp -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p udp --dport ntp -j ACCEPT
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -p tcp --dport 25 -j ACCEPT
#    workaround fuer blacklisted primaere IP (.11)
iptables -A FORWARD -i bond0.110 -s 212.9.160.12 -p tcp --dport 25 -j ACCEPT

# Den Rest weg
## iptables -A FORWARD -i bond0.110 -s 212.9.160.11 -j DROP

iptables -A FORWARD -i bond0.110 -s 212.9.160.12 -j DROP

# th, Thu Apr 9 10:48:09 CEST 2009
# LFN22201487, Schutz beider Alvarion Richtfunkgeraete
# TODO: vereinfachen
iptables -A FORWARD -o bond2.201 -s 212.9.160.128/25 -d 212.9.176.51 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 212.9.190.0/24   -d 212.9.176.51 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 62.50.111.16/28  -d 212.9.176.51 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 212.9.160.15     -d 212.9.176.51 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201                     -d 212.9.176.51 -j DROP -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 212.9.160.128/25 -d 212.9.176.52 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 212.9.190.0/24   -d 212.9.176.52 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 62.50.111.16/28  -d 212.9.176.52 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201 -s 212.9.160.15     -d 212.9.176.52 -j ACCEPT -m comment --comment "Richtfunkgeraete"
iptables -A FORWARD -o bond2.201                     -d 212.9.176.52 -j DROP -m comment --comment "Richtfunkgeraete"

# mcg, Fri Apr 24 23:13:19 CEST 2015
# Richtfunkgeraete bei Sauter und in VdL19 beschuetzen
# TODO: vereinfachen
iptables -A FORWARD -o bond2.234 -s 212.9.160.128/25 -d 212.9.169.168/29 -j ACCEPT -m comment --comment "Richtfunkgeraete Sauter/VDL19"
iptables -A FORWARD -o bond2.234 -s 212.9.190.0/24   -d 212.9.169.168/29 -j ACCEPT -m comment --comment "Richtfunkgeraete Sauter/VDL19"
iptables -A FORWARD -o bond2.234 -s 62.50.111.16/28  -d 212.9.169.168/29 -j ACCEPT -m comment --comment "Richtfunkgeraete Sauter/VDL19"
iptables -A FORWARD -o bond2.234 -s 212.9.160.15     -d 212.9.169.168/29 -j ACCEPT -m comment --comment "Richtfunkgeraete Sauter/VDL19"
iptables -A FORWARD -o bond2.234 -s 212.9.183.0/25   -d 212.9.169.168/29 -j ACCEPT -m comment --comment "Richtfunkgeraete Sauter/VDL19"
iptables -A FORWARD -o bond2.234                     -d 212.9.169.168/29 -j DROP -m comment --comment "Richtfunkgeraete Sauter/VDL19"

# mcg, Wed Jan 30 10:05:30 CET 2019
# iKVM serv02.starline.de
iptables -A FORWARD -o bond0.130 -d 213.178.160.133 -p udp --dport ntp -j DROP

# ----------------------------------------------------------------------
# mcg, Mon Mar 18 15:57:57 CET 2019
# Sun Dec 19 19:34:31 CET 2021 -rodney@LF.net
# - ueberarbeitet
#
# hivemanager.lf.net 212.9.161.124
# hivemanager2.lf.net 212.9.161.121
# hivemanager-test.lf.net 212.9.161.123

iptables -N HIVEMANAGER_FILTER > /dev/null 2>&1 || true
iptables -F HIVEMANAGER_FILTER

iptables -A HIVEMANAGER_FILTER -s 212.9.160.0/24          -j ACCEPT
iptables -A HIVEMANAGER_FILTER -s 212.9.190.0/24          -j ACCEPT
iptables -A HIVEMANAGER_FILTER -s 62.50.111.16/28         -j ACCEPT
iptables -A HIVEMANAGER_FILTER -s 212.9.183.0/25          -j ACCEPT
iptables -A HIVEMANAGER_FILTER -s 62.50.111.1             -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p tcp --dport 80          -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p tcp --dport 443         -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p udp --dport 12222       -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p tcp ! --syn --sport 25  -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p tcp ! --syn --sport 22  -j ACCEPT
iptables -A HIVEMANAGER_FILTER -p tcp ! --syn --sport 443 -j ACCEPT

# Von Norman, 10.02.2022
iptables -A HIVEMANAGER_FILTER -p tcp --dport 22         -j ACCEPT
iptables -A HIVEMANAGER_FILTER                           -j DROP

# chain aktivieren fuer DST-Address:
#iptables -A FORWARD -o bond0.113 -d 212.9.161.121 -j HIVEMANAGER_FILTER
#iptables -A FORWARD -o bond0.113 -d 212.9.161.123 -j HIVEMANAGER_FILTER
#iptables -A FORWARD -o bond0.113 -d 212.9.161.124 -j HIVEMANAGER_FILTER

# ----------------------------------------------------------------------
# Fri Dec 17 16:45:05 CET 2021 -rodney@LF.net
# - Chain f. Schutz eines Proxmox-VLANs
iptables -N PROXMOX_VLAN > /dev/null 2>&1 || true
iptables -F PROXMOX_VLAN

iptables -A PROXMOX_VLAN -s 212.9.160.128/25   -j ACCEPT -m comment --comment "Office VDL"
iptables -A PROXMOX_VLAN -s 212.9.190.0/24     -j ACCEPT -m comment --comment "Office R27"
iptables -A PROXMOX_VLAN -s 62.50.111.16/28    -j ACCEPT -m comment --comment "monitor.lf.net"
iptables -A PROXMOX_VLAN -s 212.9.160.15       -j ACCEPT -m comment --comment "service.lf.net"
iptables -A PROXMOX_VLAN -s 212.9.160.5        -j ACCEPT -m comment --comment "time3.lf.net"
iptables -A PROXMOX_VLAN -s 212.9.183.0/25     -j ACCEPT -m comment --comment "LF MA OpenVPN"
iptables -A PROXMOX_VLAN -s 212.9.160.1        -j ACCEPT -m comment --comment "ns.lf.net"
iptables -A PROXMOX_VLAN -s 62.50.111.1        -j ACCEPT -m comment --comment "res2.lf.net"

# Traffic der Proxmox-Hosts untereinander.
iptables -A PROXMOX_VLAN -m set --match-set lfnet-proxmox src -j ACCEPT -m comment --comment "LFNET Proxmox Traffic"

#iptables -A PROXMOX_VLAN -s 212.9.176.64/26    -j ACCEPT -m comment --comment "p02nXX und vzhosts, VLAN96"
#iptables -A PROXMOX_VLAN -s 62.50.111.192/26   -j ACCEPT -m comment --comment "p03nXX VLAN97"
#iptables -A PROXMOX_VLAN -s 62.50.113.0/26     -j ACCEPT -m comment --comment "p04nXX, p05nXX: VLAN93"
#iptables -A PROXMOX_VLAN -s 213.178.162.192/26 -j ACCEPT -m comment --comment "vzhostXX - TODO: remove"
#iptables -A PROXMOX_VLAN -s 62.50.113.64/27    -j ACCEPT -m comment --comment "p06nXX VLAN134"

iptables -A PROXMOX_VLAN -s 213.178.160.80/30  -j ACCEPT -m comment --comment "puppet"

# TODO, ACHTUNG: Was ist, wenn jemand mit Source-Port 9103 z.B. auf unseren SSH Port zugreift?
iptables -A PROXMOX_VLAN -p tcp --sport 80     -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -p tcp --sport 9103   -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -p tcp --sport 873    -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -p tcp --sport 22     -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -p tcp --sport 443    -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -p icmp               -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
iptables -A PROXMOX_VLAN -s 213.178.170.169    -j ACCEPT -m comment --comment "TODO: unklar"
#iptables -A PROXMOX_VLAN                       -j LOG --log-prefix 'PROXMOX_VLAN_DROP ' # DEBUG
iptables -A PROXMOX_VLAN                       -j DROP


# -------------------------------------------------------------------------------------------
# Wed Apr 23 13:01:18 CEST 2025 -rodney@LF.net
# - Am Beispiel p06nXX, Ansatz, die Regeln enger zu gestalten

ipset create tmp-log-targets hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0

# LF CIDRs
if true; then
  ipset add tmp 62.50.96.0/19
  ipset add tmp 212.9.160.0/19
  ipset add tmp 213.178.160.0/19
  ipset add tmp 212.118.160.0/19
  ipset add tmp 185.217.144.0/22
fi

ipset swap tmp-log-targets tmp
ipset destroy tmp

iptables -N PROXMOX_VLAN2 > /dev/null 2>&1 || true
iptables -F PROXMOX_VLAN2

#iptables -A PROXMOX_VLAN2 -d 62.50.113.66/32 -j ACCEPT -m comment --comment "ACHTUNG - NUR TEMPORAER FUER HOST-BASED-FW-TESTING!!!" # DEBUG

iptables -A PROXMOX_VLAN2 -p tcp -m tcp ! --syn -j ACCEPT -m comment --comment "Accept established (non-syn)"
iptables -A PROXMOX_VLAN2 -s 212.9.160.128/25   -j ACCEPT -m comment --comment "Office VDL"
iptables -A PROXMOX_VLAN2 -s 212.9.190.0/24     -j ACCEPT -m comment --comment "Office R27"
iptables -A PROXMOX_VLAN2 -s 62.50.111.16/28    -j ACCEPT -m comment --comment "monitor.lf.net"
iptables -A PROXMOX_VLAN2 -s 212.9.160.15       -j ACCEPT -m comment --comment "service.lf.net"
#iptables -A PROXMOX_VLAN2 -s 212.9.160.5        -j ACCEPT -m comment --comment "time3.lf.net"
iptables -A PROXMOX_VLAN2 -s 212.9.183.0/25     -j ACCEPT -m comment --comment "LF MA OpenVPN"
iptables -A PROXMOX_VLAN2 -s 212.9.160.1 -p udp --sport 53 -j ACCEPT -m comment --comment "ns.lf.net"
iptables -A PROXMOX_VLAN2 -s 62.50.111.1 -p udp --sport 53 -j ACCEPT -m comment --comment "res2.lf.net"

# Traffic der Proxmox-Hosts untereinander
iptables -A PROXMOX_VLAN2 -m set --match-set lfnet-proxmox src -m set --match-set lfnet-proxmox dst -j ACCEPT -m comment --comment "LFNET Intra-Proxmox-Traffic"

# iptables -A PROXMOX_VLAN2 -s 213.178.160.80/30 -j ACCEPT -m comment --comment "puppet"
iptables -A PROXMOX_VLAN2 -p icmp -j ACCEPT -m comment --comment "TODO: src-port-fake Vulnerability?"
#iptables -A PROXMOX_VLAN2 -s 213.178.170.169    -j ACCEPT -m comment --comment "TODO: unklar"

# Logging
iptables -A PROXMOX_VLAN2 \
  -m set --match-set tmp-log-targets src \
  -m set --match-set tmp-log-targets dst \
  -j LOG --log-prefix 'PROXMOX_VLAN2_DROP ' -m comment --comment "Log drops within our networks"

#iptables -A PROXMOX_VLAN2 -j LOG --log-prefix 'PROXMOX_VLAN2_DROP ' # DEBUG
iptables -A PROXMOX_VLAN2                       -j DROP


#
# Fri Dec 17 16:55:38 CET 2021 -rodney@LF.net
# - pXXnXX- und vzhost-Netze abschotten
#
# - TODO: Sperrung der kompletten VLAN96, VLAN97, VLAN93 etc.
#   o Sollten wir nicht *alles* sperren, was auf bond0.XX rausgeht?
#     Warum nur die mit -d xxx/xx genannten Netze?
#   o A: alles sperren geht nicht, weil zum Beispiel auch routed Traffic zu den LXCs auf p04nXX geht.
#   o Check, was laeuft sonst noch ueber die Interfaces? Z.B.:
#
#     tcpdump -ni bond0.97 not net 212.9.176.64/26
#
# VLAN 96, p02nXX u. div. vzhosts
# - ACHTUNG: in VLAN96 befindet sich anscheinend noch genug anderes Zeug,
#   so dass wir nicht den kompletten outgoing traffic sperren koennen.
iptables -A FORWARD -o bond0.96 -d 212.9.176.64/26 -j PROXMOX_VLAN -m comment --comment "p0xnXX u. vzhosts, VLAN96"

# VLAN 97, p03n*
iptables -A FORWARD -o bond0.97 -d 62.50.111.192/26 -j PROXMOX_VLAN -m comment --comment "p03nXX, VLAN97"
#iptables -A FORWARD -o bond0.97 -j PROXMOX_VLAN -m comment --comment "p03nXX, VLAN97"


# VLAN 93, p04n*, p05n*, 62.50.113.0/26
iptables -A FORWARD -o bond0.93 -d 62.50.113.0/26 -j PROXMOX_VLAN -m comment --comment "p04nXX, VLAN93"

#iptables -A FORWARD -s 37.209.123.184 -d 62.50.113.0/26 -j DROP -m comment --comment "DEBUG: Daniel"


# Wed Apr 23 12:01:45 CEST 2025 -rodney@LF.net
# - VLAN 134, p06nXX, 62.50.113.64/27
# - neue Version "PROXMOX_VLAN2", mit eingeschraenkteren Regeln
# - ACHTUNG, FIXME, das ist auf Basis der Interface-Namen zu unsicher!
iptables -A FORWARD -o eth5.134 -j PROXMOX_VLAN2 -m comment --comment "p06nXX, VLAN134"


# mcg, Wed Jul 06 13:19:04 CEST 2016
# LFN24360159 sw1-k25 abschotten
# TODO: vereinfachen
iptables -N TELNET_FROM_LFNET > /dev/null 2>&1 || true
iptables -F TELNET_FROM_LFNET

iptables -A TELNET_FROM_LFNET -s 212.9.160.128/25 -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 212.9.190.0/24   -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 62.50.111.16/28  -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 212.9.160.15     -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 212.9.183.0/25   -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 212.9.160.1      -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET -s 62.50.111.1      -p tcp --dport 23 -j ACCEPT
iptables -A TELNET_FROM_LFNET                     -p tcp --dport 23 -j DROP

iptables -A FORWARD -o bond0.100 -d 212.9.160.92     -j TELNET_FROM_LFNET
iptables -A FORWARD -o bond0.100 -d 212.9.164.113    -j TELNET_FROM_LFNET
iptables -A FORWARD -o bond0.100 -d 212.9.169.161    -j TELNET_FROM_LFNET
iptables -A FORWARD -o bond0.100 -d 212.9.169.129    -j TELNET_FROM_LFNET
iptables -A FORWARD -o bond0.100 -d 212.9.184.193    -j TELNET_FROM_LFNET


# mcg, Wed Jul 06 13:19:04 CEST 2016
# LFN24360159 sw1-koe5 abschotten
iptables -A FORWARD -o bond0.100 -s 212.9.160.128/25    -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.190.0/24      -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.16/28     -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.15        -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.183.0/25      -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.1         -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.1         -d 212.9.160.93 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100                        -d 212.9.160.93 -p tcp --dport 23 -j DROP
iptables -A FORWARD -o bond0.100 -s 212.9.160.128/25    -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.190.0/24      -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.16/28     -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.15        -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.183.0/25      -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.1         -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.1         -d 212.9.164.81 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100                        -d 212.9.164.81 -p tcp --dport 23 -j DROP
iptables -A FORWARD -o bond0.100 -s 212.9.160.128/25    -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.190.0/24      -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.16/28     -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.15        -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.183.0/25      -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.1         -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.1         -d 212.9.165.57 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100                        -d 212.9.165.57 -p tcp --dport 23 -j DROP
iptables -A FORWARD -o bond0.100 -s 212.9.160.128/25    -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.190.0/24      -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.16/28     -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.15        -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.183.0/25      -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.1         -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.1         -d 212.9.170.193 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100                        -d 212.9.170.193 -p tcp --dport 23 -j DROP
iptables -A FORWARD -o bond0.100 -s 212.9.160.128/25    -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.190.0/24      -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.16/28     -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.15        -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.183.0/25      -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 212.9.160.1         -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100 -s 62.50.111.1         -d 212.9.170.137 -p tcp --dport 23 -j ACCEPT
iptables -A FORWARD -o bond0.100                        -d 212.9.170.137 -p tcp --dport 23 -j DROP

# LFN19361720, telnet filter fuer dsl-gw.ispeg.eu (08/2016)
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.128/25 -d 212.9.160.21 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.190.0/24   -d 212.9.160.21 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 62.50.111.16/28  -d 212.9.160.21 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.15     -d 212.9.160.21 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.183.0/25   -d 212.9.160.21 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23                     -d 212.9.160.21 -j DROP -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.128/25 -d 212.9.161.26 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.190.0/24   -d 212.9.161.26 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 62.50.111.16/28  -d 212.9.161.26 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.15     -d 212.9.161.26 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.183.0/25   -d 212.9.161.26 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23                     -d 212.9.161.26 -j DROP -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.128/25 -d 212.9.164.226 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.190.0/24   -d 212.9.164.226 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 62.50.111.16/28  -d 212.9.164.226 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.15     -d 212.9.164.226 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.183.0/25   -d 212.9.164.226 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23                     -d 212.9.164.226 -j DROP -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.128/25 -d 212.9.164.241 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.190.0/24   -d 212.9.164.241 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 62.50.111.16/28  -d 212.9.164.241 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.15     -d 212.9.164.241 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.183.0/25   -d 212.9.164.241 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23                     -d 212.9.164.241 -j DROP -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.128/25 -d 212.9.171.160/29 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.190.0/24   -d 212.9.171.160/29 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 62.50.111.16/28  -d 212.9.171.160/29 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.160.15     -d 212.9.171.160/29 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23 -s 212.9.183.0/25   -d 212.9.171.160/29 -j ACCEPT -m comment --comment "LFN19361720"
iptables -A FORWARD -p tcp --dport 23                     -d 212.9.171.160/29 -j DROP -m comment --comment "LFN19361720"


# Managementnetz 299
iptables -A FORWARD -o bond0.299 -s 212.9.160.128/25 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.190.0/24 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.160.65 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 62.50.111.16/28 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.160.15 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.183.0/25 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.160.1 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 212.9.160.5 -j ACCEPT
iptables -A FORWARD -o bond0.299 -s 62.50.111.1 -j ACCEPT
iptables -A FORWARD -o bond0.299 -j DROP

iptables -A FORWARD -o bond2.299 -s 212.9.160.128/25 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.190.0/24 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.160.65 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 62.50.111.16/28 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.160.15 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.183.0/25 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.160.1 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 212.9.160.5 -j ACCEPT
iptables -A FORWARD -o bond2.299 -s 62.50.111.1 -j ACCEPT
iptables -A FORWARD -o bond2.299 -j DROP


# LFN17434006
iptables -A FORWARD -o bond0.235 -s 212.9.160.128/25 -d 212.9.169.88/29 -j ACCEPT
iptables -A FORWARD -o bond0.235 -s 212.9.190.0/24   -d 212.9.169.88/29 -j ACCEPT
iptables -A FORWARD -o bond0.235 -s 62.50.111.16/28  -d 212.9.169.88/29 -j ACCEPT
iptables -A FORWARD -o bond0.235 -s 212.9.160.15     -d 212.9.169.88/29 -j ACCEPT
iptables -A FORWARD -o bond0.235 -s 212.9.183.0/25   -d 212.9.169.88/29 -j ACCEPT
iptables -A FORWARD -o bond0.235                     -d 212.9.169.88/29 -j DROP

#
# Gesperrte Gegenstellen (bitte Ticket Nr. im Kommentar angeben)
# Such-Tags: Blacklists blacklisting black-list
# ----------------------
#
# z.B. Video Traffic, DoS, etc.
# Seit Wochen massives verteiltes password probing aus Hong Kong, Details siehe LFN31469822
iptables -A FORWARD -p tcp -s 5.188.206.0/24 -j DROP -m comment --comment "LFN31469822"


#
# Anti-spam Filter
# ----------------
#
# fuer Kunden, die ihre offenen mail-relay server nicht
# dicht bekommen, werden
# - hier Filter gesetzt
# - auf mail.LF.net:~exim/smarthostrelay eine Weiterleitung eingetragen

# mh, Thu Jun 17 09:44:24 CEST 2004
# LFN28086428  mail.lbg-online.de offenes Relay, relayt ueber mail.LF.net, dieser dadurch
# bei spamcop gelistet :-(
# mh, Fri Mar 11 12:10:17 CET 2005, immer noch alles offen, Filter bleiben
# LFN12111045
# Smarthostrelay mail.LF.net
iptables -A FORWARD -p tcp -s 212.9.160.2 -d 213.178.172.92 --dport 25 -j ACCEPT
iptables -A FORWARD -p tcp -s 194.25.152.9 -d 213.178.172.92 --dport 25 -j ACCEPT
iptables -A FORWARD -p tcp -d 213.178.172.92 --dport 25 -j DROP

# mail.bessey.de (212.9.170.132)
# Online Spamfilter auf mail.LF.net LFN27113688
iptables -A FORWARD -p tcp -s 212.9.160.2 -d 212.9.170.132 --dport 25 -j ACCEPT
iptables -A FORWARD -p tcp -d 212.9.170.132 --dport 25 -j DROP

#
# Kundenfilter, spezielle Setups auf Wunsch
# ------------
#

# 213.178.172.147 ISPgate DSL, mail.tr-sys.de TRSYS
# Kunde tr-sys wuenscht Einlieferung nur ueber Fallbacks
# spamfilterrelay auf mail.LF.net
iptables -A FORWARD -p tcp -s 212.9.160.2 -d 213.178.172.147 --dport 25 -j ACCEPT
iptables -A FORWARD -p tcp -s 194.25.152.9 -d 213.178.172.147 --dport 25 -j ACCEPT
# Antwortpakete von SMTP ausgehend
iptables -A FORWARD -p tcp --sport 25 -d 213.178.172.147 -j ACCEPT
# Allow HTTP REPLAYs
iptables -A FORWARD -p tcp --sport 80 -d 213.178.172.147 -j ACCEPT
iptables -A FORWARD -p tcp --sport 443 -d 213.178.172.147 -j ACCEPT
# Allow SSH
iptables -A FORWARD -p tcp -d 213.178.172.147 --dport 22 -j ACCEPT
iptables -A FORWARD -p tcp --sport 22 -d 213.178.172.147 -j ACCEPT
# Allow PASSIVE FTP
iptables -A FORWARD -p tcp -d 213.178.172.147 --dport 20 -j ACCEPT
iptables -A FORWARD -p tcp --sport 20 -d 213.178.172.147 -j ACCEPT
iptables -A FORWARD -p tcp -d 213.178.172.147 --dport 21 -j ACCEPT
iptables -A FORWARD -p tcp --sport 21 -d 213.178.172.147 -j ACCEPT
# Allow UDP DNS REPLYs
iptables -A FORWARD -p udp --sport 53 -d 213.178.172.147 -j ACCEPT
# Allow UDP NTP/SNTP
iptables -A FORWARD -p udp --sport 123 -d 213.178.172.147 -j ACCEPT
# Deny any other TCP UDP
iptables -A FORWARD -p tcp --tcp-flags RST RST -d 213.178.172.147 -j ACCEPT
iptables -A FORWARD -p tcp --tcp-flags ACK ACK -d 213.178.172.147 -j ACCEPT
iptables -A FORWARD -p tcp -d 213.178.172.147 -j DROP
iptables -A FORWARD -p udp -d 213.178.172.147 -j DROP

# RiFu Schuetzinger, Schutz der airmux Geraete:
iptables -A FORWARD -o bond2.226 -s 62.50.111.16/28  -d 212.9.169.58/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -s 62.50.111.16/28  -d 212.9.169.59/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -s 212.9.190.0/24 -d 212.9.169.58/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -s 212.9.190.0/24 -d 212.9.169.59/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -s 212.9.160.128/25 -d 212.9.169.58/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -s 212.9.160.128/25 -d 212.9.169.59/32 -j ACCEPT -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -d 212.9.169.58/32 -j DROP -m comment --comment "Schuetzinger RiFu"
iptables -A FORWARD -o bond2.226 -d 212.9.169.59/32 -j DROP -m comment --comment "Schuetzinger RiFu"

# LFN25308563 -> kein ntp auf dsl-gw.ispeg.de erlauben
#-A FORWARD -o bond3 -p udp -d 212.9.161.26 --dport 123 -j REJECT
#-A FORWARD -o bond3 -p tcp -d 212.9.161.26 --dport 123 -j REJECT

# LFN26462266, eximl nail21 Sicherheitsluecken
#iptables -A FORWARD -p tcp -d 212.9.190.126 --dport 25 -j REJECT -m comment --comment "LFN26462266 exim nail21"


# -----------------------------------------------------------------------
# LFN22321790
# ssh-Zugriff von 144.0.0.0/16 auf ISPeG-IPs sperren
ipset create LFN22321790-ispeg-server hash:net > /dev/null 2>&1 || true
ipset flush LFN22321790-ispeg-server

ipset add LFN22321790-ispeg-server 212.9.161.0/28
ipset add LFN22321790-ispeg-server 212.9.161.16/30
ipset add LFN22321790-ispeg-server 212.9.161.24/30
ipset add LFN22321790-ispeg-server 212.9.164.224/30
ipset add LFN22321790-ispeg-server 212.9.171.192/27
ipset add LFN22321790-ispeg-server 212.9.176.160/29
ipset add LFN22321790-ispeg-server 212.9.164.240/28

iptables -A FORWARD -p tcp -s 144.0.0.0/16 -m set --match-set LFN22321790-ispeg-server dst -j DROP

# -------------------------------------------------------------------------------
# CVE-2019-15846 LFN23432266 Filter wg. exim root exploit fuer nicht pachbare Systeme

ipset create LFN23432266-exim-exploit hash:ip > /dev/null 2>&1 || true
ipset flush LFN23432266-exim-exploit

ipset add LFN23432266-exim-exploit 62.50.112.85
ipset add LFN23432266-exim-exploit 62.50.112.168
ipset add LFN23432266-exim-exploit 212.9.171.101
ipset add LFN23432266-exim-exploit 213.178.166.51
ipset add LFN23432266-exim-exploit 212.9.188.246
ipset add LFN23432266-exim-exploit 62.50.112.102
ipset add LFN23432266-exim-exploit 212.9.188.175
ipset add LFN23432266-exim-exploit 212.9.179.80
ipset add LFN23432266-exim-exploit 213.178.166.12
ipset add LFN23432266-exim-exploit 212.9.176.13
ipset add LFN23432266-exim-exploit 212.9.188.168
ipset add LFN23432266-exim-exploit 212.9.188.177
ipset add LFN23432266-exim-exploit 212.9.161.92
ipset add LFN23432266-exim-exploit 212.9.177.156
ipset add LFN23432266-exim-exploit 62.50.112.138
ipset add LFN23432266-exim-exploit 212.9.179.76
ipset add LFN23432266-exim-exploit 62.50.112.165
ipset add LFN23432266-exim-exploit 62.50.112.167
ipset add LFN23432266-exim-exploit 212.9.188.249
ipset add LFN23432266-exim-exploit 212.9.171.100
ipset add LFN23432266-exim-exploit 213.178.166.74
ipset add LFN23432266-exim-exploit 212.9.177.155
ipset add LFN23432266-exim-exploit 62.50.112.103
ipset add LFN23432266-exim-exploit 212.9.188.165
ipset add LFN23432266-exim-exploit 212.9.188.251
ipset add LFN23432266-exim-exploit 212.9.171.97
ipset add LFN23432266-exim-exploit 62.50.112.86
ipset add LFN23432266-exim-exploit 62.50.112.164
ipset add LFN23432266-exim-exploit 62.50.112.88
ipset add LFN23432266-exim-exploit 62.50.112.166
ipset add LFN23432266-exim-exploit 212.9.188.228
ipset add LFN23432266-exim-exploit 212.9.185.175
ipset add LFN23432266-exim-exploit 212.9.171.103
ipset add LFN23432266-exim-exploit 62.50.112.139
ipset add LFN23432266-exim-exploit 212.9.161.115
ipset add LFN23432266-exim-exploit 62.50.112.106
ipset add LFN23432266-exim-exploit 213.178.160.90
ipset add LFN23432266-exim-exploit 213.178.166.17
ipset add LFN23432266-exim-exploit 176.94.103.138
ipset add LFN23432266-exim-exploit 212.9.171.102
ipset add LFN23432266-exim-exploit 212.9.188.250
ipset add LFN23432266-exim-exploit 212.9.188.164
ipset add LFN23432266-exim-exploit 62.50.120.72
ipset add LFN23432266-exim-exploit 213.178.166.36
ipset add LFN23432266-exim-exploit 176.94.103.140
ipset add LFN23432266-exim-exploit 62.50.112.101
ipset add LFN23432266-exim-exploit 62.50.112.133
ipset add LFN23432266-exim-exploit 212.9.161.114
ipset add LFN23432266-exim-exploit 62.50.112.84
ipset add LFN23432266-exim-exploit 213.178.166.22
ipset add LFN23432266-exim-exploit 62.50.112.105
ipset add LFN23432266-exim-exploit 62.50.112.135
ipset add LFN23432266-exim-exploit 212.9.188.252
ipset add LFN23432266-exim-exploit 213.178.166.21
ipset add LFN23432266-exim-exploit 62.50.112.100
ipset add LFN23432266-exim-exploit 212.9.170.133
ipset add LFN23432266-exim-exploit 62.50.112.107
ipset add LFN23432266-exim-exploit 62.50.120.76
ipset add LFN23432266-exim-exploit 62.50.112.109
ipset add LFN23432266-exim-exploit 212.9.188.248
ipset add LFN23432266-exim-exploit 212.9.179.79
ipset add LFN23432266-exim-exploit 213.178.160.91
ipset add LFN23432266-exim-exploit 62.50.112.111
ipset add LFN23432266-exim-exploit 62.50.120.69
ipset add LFN23432266-exim-exploit 62.50.112.134
ipset add LFN23432266-exim-exploit 213.178.162.162
ipset add LFN23432266-exim-exploit 212.9.176.12
ipset add LFN23432266-exim-exploit 212.9.188.167
ipset add LFN23432266-exim-exploit 212.9.171.99
ipset add LFN23432266-exim-exploit 62.50.112.110
ipset add LFN23432266-exim-exploit 212.9.183.209
ipset add LFN23432266-exim-exploit 212.9.183.176
ipset add LFN23432266-exim-exploit 212.9.186.214

iptables -A FORWARD -p tcp -s 144.0.0.0/16 -m set --match-set LFN23432266-exim-exploit dst -j DROP

# LFN35439379 auth-scans
iptables -A FORWARD -s 185.234.216.0/22  -j DROP

# LFN25461509 WRS
iptables -A FORWARD -s 212.9.178.90/32 -d 172.105.191.235 -j DROP
iptables -A FORWARD -s 212.9.178.90/32 -p tcp --dport 9999 -j DROP

# LFN21474042 2022-01-18
iptables -A FORWARD -d 213.178.160.39/32 -p tcp --dport 80 -j DROP
iptables -A FORWARD -d 213.178.160.39/32 -p tcp --dport 443 -j DROP

#
# # Footer --------------------------------------------------
# cat4 <<.eof
# # Optional: reject some traffic instead of simply dropping it.
# #-A INPUT -p tcp -j REJECT
# #
# # Reject with given reason:
# #-A INPUT -p tcp -j REJECT --reject-with icmp-host-prohibited
#
# COMMIT
# .eof
#
# cat6 <<.eof
# COMMIT
# .eof


echo "$0: Success." >&2

