#!/bin/bash

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

# ---------------------------------------------------------
# ipsets

# black-src ----------------------------
ipset create black-src hash:net timeout 600 > /dev/null 2>&1
ipset create tmp hash:net timeout 600 > /dev/null 2>&1

# Hetzner? Scan auf EDE onlineshop 16.11.2021
ipset add tmp 144.76.224.0/24 --exist timeout 0
ipset add tmp 144.76.36.146/32 --exist timeout 0
ipset add tmp 176.9.10.194/32 --exist timeout 0
ipset add tmp 188.40.75.228/32 --exist timeout 0
ipset add tmp 188.40.85.174/32 --exist timeout 0
ipset add tmp 5.9.172.212/32 --exist timeout 0
ipset add tmp 88.198.0.120/32 --exist timeout 0

ipset swap tmp black-src
ipset destroy tmp



# black-sets-src ----------------------------

ipset create black-sets-src list:set timeout 600 > /dev/null 2>&1
ipset create tmp list:set timeout 600 > /dev/null 2>&1

ipset add tmp black-src --exist timeout 0 # blacklistet source IP, *immer* blocken

ipset swap tmp black-sets-src
ipset destroy tmp



#exit 0

# Default is to keep the existing policy untouched.
#iptables --policy INPUT DROP
#iptables --policy FORWARD DROP



# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

# FIXME, geht das eleganter?
#while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
#iptables -I FORWARD -j $IPT-FORWARD

# FIXME, geht das eleganter?
iptables -N DOCKER-USER > /dev/null 2>&1
iptables -F DOCKER-USER
iptables -I DOCKER-USER -j $IPT-FORWARD

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

# Allow all traffic within a set of networks
MYSET=iptables-autoapply-mynetworks
ipset flush $MYSET
ipset destroy $MYSET

ipset create $MYSET hash:net > /dev/null 2>&1
#ipset add $MYSET 62.50.100.2/27
ipset add $MYSET 10.0.0.0/8
ipset add $MYSET 192.168.0.0/16
ipset add $MYSET 172.16.0.0/12
ipset add $MYSET 127.0.0.0/8

iptables -A $IPT -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"

iptables -A $IPT -m set --match-set $MYSET src,dst -j RETURN

iptables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN
iptables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN

# DEBUG: allow all ssh incoming
#iptables -I $IPT -p tcp --dport 22 -j RETURN

# Allow incoming DNS queries
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 53 -j RETURN"
#echo4 "-A INPUT -m state --state NEW -p udp --dport 53 -j RETURN"

# Allow incoming SMTP
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 25 -j RETURN"

iptables -A $IPT -m state --state NEW -p tcp --dport 80 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp --dport 443 -j RETURN
#iptables -A $IPT -m state --state NEW -p tcp --dport 22 -j RETURN
#iptables -A $IPT -m state --state NEW -p tcp --dport 9200 -j RETURN

iptables -A $IPT -m state --state NEW -p tcp --dst 62.50.114.114 --dport 22 -j RETURN

# Netdata
iptables -A $IPT -m state --state NEW -p tcp --src 212.9.190.0/24 --dport 19999 -j RETURN

# Prometheus
iptables -A $IPT -m state --state NEW -p tcp --src 212.9.190.0/24 --dport 9090 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp --src 62.50.111.16/28 --dport 9090 -m comment --comment "monitor.lf.net to prometheus" -j RETURN

#iptables -A $IPT -m state --state NEW -p tcp --dport 19999 -j RETURN # FIXME!!!
#iptables -A $IPT -m state --state NEW -p tcp --dport 9090 -j RETURN # FIXME!!!


# https://superuser.com/questions/1471265/open-iptables-whithin-docker-compose-network-and-one-external-server
iptables -A $IPT -m conntrack -p tcp --ctorigdstport 8022 --ctorigdst 212.9.161.112/32 -j RETURN
iptables -A $IPT -m conntrack -p tcp --ctorigdstport 8023 --ctorigdst 212.9.161.112/32 -j RETURN
iptables -A $IPT -m conntrack -p tcp --ctorigdstport 8024 --ctorigdst 212.9.161.112/32 -j RETURN
iptables -A $IPT -m conntrack -p tcp --ctorigdstport 8025 --ctorigdst 212.9.161.112/32 -j RETURN



# Allow incoming NRPE -----------------------------------------
S=""
S="$S 62.50.111.16/28"      # monitor.lf.net
S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 5666 -j RETURN
done

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN


# Allow SSH from known sources ---------------------------
S=""
S="$S 212.9.190.0/24"       # LF.net Office
S="$S 212.9.190.18/32"      # zen.lf.net
S="$S 212.9.160.200/32"     # outcast.lf.net
S="$S 213.178.172.16/32"    # volz.eu
S="$S 212.9.183.0/25"       # LF.net VPN network
S="$S 212.9.190.49/32"      # hydra3.lf.net
S="$S 62.50.111.16/28"      # monitor.lf.net
S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 22 -j RETURN
done

# Allow Bacula TCP/9102 from backup.lf.net --------------
S=""
S="$S 213.178.160.3/32"
S="$S 213.178.162.248/32"
S="$S 212.9.160.62/32"
S="$S 212.9.160.106/32"
S="$S 212.9.160.135/32"
S="$S 212.9.161.106/32"
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 9102 -j RETURN
done

# # Allow NFS ----------------------------------------------
# for i in 10.1.1.0/24
# do
#
# cat4 <<.eof
#
# # Allow NFS for $i ------------------------------
# -A INPUT -s $i -m state --state NEW -p udp --dport 111 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 111 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 2049 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 32803 -j RETURN
# -A INPUT -s $i -m state --state NEW -p udp --dport 32769 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 892 -j RETURN
# -A INPUT -s $i -m state --state NEW -p udp --dport 892 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 875 -j RETURN
# -A INPUT -s $i -m state --state NEW -p udp --dport 875 -j RETURN
# -A INPUT -s $i -m state --state NEW -p tcp --dport 662 -j RETURN
# -A INPUT -s $i -m state --state NEW -p udp --dport 662 -j RETURN
# .eof
#
# done



#
## Footer --------------------------------------------------
#cat4 <<.eof
## Optional: reject some traffic instead of simply dropping it.
##-A INPUT -p tcp -j REJECT
##
## Reject with given reason:
##-A INPUT -p tcp -j REJECT --reject-with icmp-host-prohibited
#
#COMMIT
#.eof
#
#cat6 <<.eof
#COMMIT
#.eof

#iptables -A $IPT -j RETURN

# Last rule should always be a DROP!
iptables -A $IPT -j DROP


# IPv6 =======================================================

ip6tables --policy INPUT DROP
ip6tables -F INPUT

ip6tables --policy FORWARD DROP
ip6tables -F FORWARD


# EOF
