#!/bin/bash

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

set -x
set -Eeu -o pipefail

function trap_error {
  # trap_cleanup # in case we want to cleanup something
  echo "$0: failed in line $*" >&2
  exit 2
}

trap 'trap_error $LINENO' ERR

#exit 0

# Default is to keep the existing policy untouched.
#iptables --policy INPUT DROP
#iptables --policy FORWARD DROP

# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null || true                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null || true                # New chain
iptables -N $IPT 2> /dev/null || true                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

# FIXME, geht das eleganter?
while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I FORWARD -j $IPT-FORWARD

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

# Allow all traffic within a set of networks
MYSET=iptables-autoapply-mynetworks
ipset flush $MYSET
ipset destroy $MYSET

ipset create $MYSET hash:net > /dev/null 2>&1
#ipset add $MYSET 62.50.100.2/27
ipset add $MYSET 10.0.0.0/8
ipset add $MYSET 192.168.0.0/16
ipset add $MYSET 172.16.0.0/16
ipset add $MYSET 127.0.0.0/8


# -------------------------------------------------------
# LF.net trusted networks
ipset create LF6 hash:net family inet6 comment > /dev/null 2>&1 || true
ipset destroy tmp > /dev/null 2>&1 || true
ipset create tmp hash:net family inet6 comment > /dev/null 2>&1 || true

ipset add tmp 2001:14b0:1:1:212:9:190:0/64 --comment "LF.net Office"
ipset add tmp ::/1 --comment "TMP: Allow all" # DEBUG
ipset add tmp 8000::/1 --comment "TMP: Allow all" # DEBUG
# TODO: weitere Netze?

ipset swap tmp LF6
ipset destroy tmp

iptables -A $IPT -m set --match-set $MYSET src,dst -j RETURN

# DEBUG: allow all ssh incoming
#iptables -I $IPT -p tcp --dport 22 -j RETURN

# Allow incoming DNS queries
iptables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN -m comment --comment "Open external DNS"
iptables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN

# Allow incoming SMTP
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 25 -j RETURN"

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN


# Allow SSH from known sources ---------------------------
iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp --dport 22 -j RETURN


#
## Footer --------------------------------------------------
#cat4 <<.eof
## Optional: reject some traffic instead of simply dropping it.
##-A INPUT -p tcp -j REJECT
##
## Reject with given reason:
##-A INPUT -p tcp -j REJECT --reject-with icmp-host-prohibited
#
#COMMIT
#.eof
#
#cat6 <<.eof
#COMMIT
#.eof

#iptables -A $IPT -j RETURN

# Last rule must always be a DROP!
iptables -A $IPT -j DROP


# IPv6 =======================================================

# Initialization ----------------------------------------------------------------
ip6tables -N $IPT-INPUT 2> /dev/null || true          # New chain
ip6tables -N $IPT-FORWARD 2> /dev/null || true        # New chain
ip6tables -N $IPT 2> /dev/null || true                # New chain

ip6tables -F $IPT-INPUT
ip6tables -A $IPT-INPUT -j $IPT
ip6tables -A $IPT-INPUT -j RETURN

ip6tables -F $IPT-FORWARD
ip6tables -A $IPT-FORWARD -j $IPT
ip6tables -A $IPT-FORWARD -j RETURN


ip6tables -A $IPT -p icmp -j RETURN

# Allow all traffic within a set of networks
MYSET=iptables-autoapply-mynetworks
ipset flush $MYSET || true
ipset destroy $MYSET || true

ipset create $MYSET hash:net family inet6 > /dev/null 2>&1 || true
#ipset add $MYSET 


ip6tables -A OUTPUT -m state --state NEW -j RETURN



ip6tables -F $IPT

# FIXME, geht das eleganter?
while ip6tables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
ip6tables -I INPUT -j $IPT-INPUT

# FIXME, geht das eleganter?
while ip6tables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
ip6tables -I FORWARD -j $IPT-FORWARD

# Allow all established traffic
ip6tables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN



# ===========================


ip6tables --policy INPUT ACCEPT
#ip6tables -F INPUT

ip6tables --policy FORWARD ACCEPT
#ip6tables -F FORWARD



# Allow SSH from known sources ---------------------------
#ip6tables -A $IPT -m set --match-set LF6 src -m state --state NEW -p tcp --dport 22 -j LOG --log-prefix "XXXXXXXXXXXXXXX ALLOW: "
#ip6tables -A $IPT -m set --match-set LF6 src -m state --state NEW -p tcp --dport 22 -j RETURN

ip6tables -A $IPT -m state -s 2001:14b0:1:1:212:9:190:0/64 --state NEW -p tcp --dport 22 -j RETURN -m comment --comment "Allow LF.net Office"
ip6tables -A $IPT -p tcp --dport 22 -j DROP

#ip6tables -A $IPT -p tcp --dport 22 -j LOG --log-prefix "SSH DROP: "

ip6tables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN -m comment --comment "Open external DNS6"
ip6tables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN


# Last rule must always be a DROP!
#ip6tables -A $IPT -j LOG
#ip6tables -A $IPT -j DROP

echo "Success"

# EOF
