#!/bin/bash

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

sysctl -w net.ipv4.netfilter.ip_conntrack_max=500000

#exit 0

# Default is to keep the existing policy untouched.
#iptables --policy INPUT DROP
#iptables --policy FORWARD DROP

# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

# FIXME, geht das eleganter?
while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I FORWARD -j $IPT-FORWARD

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN

# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN


# -------------------------
# Allow all traffic within a set of networks
MYSET=iptables-autoapply-mynetworks
ipset flush $MYSET
ipset destroy $MYSET

ipset create $MYSET hash:net > /dev/null 2>&1
# FIXME, das ist heikel!
#ipset add $MYSET 10.0.0.0/8
#ipset add $MYSET 192.168.0.0/16
#ipset add $MYSET 172.16.0.0/16
ipset add $MYSET 127.0.0.0/8

# Allow access within our networks
iptables -A $IPT -m set --match-set $MYSET src,dst -j RETURN


# -------------------------------------------------------
# LF.net trusted networks
ipset create LF hash:net comment > /dev/null 2>&1
ipset create tmp hash:net comment > /dev/null 2>&1

ipset add tmp 212.9.190.0/24 --comment "LF.net Office"
ipset add tmp 212.9.190.18/32 --comment "zen.lf.net"
ipset add tmp 212.9.160.200/32 --comment "outcast.lf.net"
ipset add tmp 213.178.172.16/32 --comment "volz.eu"
ipset add tmp 212.9.183.0/25 --comment "LF.net VPN network"
ipset add tmp 212.9.190.49/32 --comment "hydra3.lf.net"
ipset add tmp 62.50.111.16/28 --comment "monitor.lf.net"
ipset add tmp 62.50.100.152/32 --comment "monitor.volz.eu"

ipset swap tmp LF
ipset destroy tmp



# ---------------------------
# "List of known networks"
# - Liste der Netze, die wir schuetzen.
# - Liste der Rechner, die bei einem 'allow any' nicht gemeint sind.
# - d.h. zum Beispiel alle die, fuer die wir direkt oder indirekt Gateway sind
#

ipset create KNOWN-CIDR hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

# - Alle Netze, in denen wir Interfaces haben
# - Aber, nicht eth0, denn das ist das externe IF.
#ip a l | egrep 'inet.*brd.*scope' | grep -v eth0 | while read a b c; do
#  ipset add tmp $b --comment "$a $b $c"
#done

# Ansatz:
# - in der route list stehen alle Netze, die wir kennen.
# - d.h. die ist hinreichend.
ip r l | grep -v default | while read a b; do
  ipset add tmp $a --comment "Route: $a $b"
done

ipset swap tmp KNOWN-CIDR
ipset destroy tmp


# ---
# "Liste der Netze/Rechner, die wir schuetzen"
ipset create KNOWN list:set timeout 0 comment > /dev/null 2>&1
ipset create tmp list:set timeout 0 comment > /dev/null 2>&1

ipset add tmp KNOWN-CIDR --exist --comment "CIDRs we know and protect"
#ipset add tmp MVISION --exist --comment "bla"

ipset swap KNOWN tmp
ipset destroy tmp


# ------------------------
# DEBUG: allow all ssh incoming
#iptables -I $IPT -p tcp --dport 22 -j RETURN

# Allow incoming DNS queries
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 53 -j RETURN"
#echo4 "-A INPUT -m state --state NEW -p udp --dport 53 -j RETURN"

# Allow incoming SMTP
#echo4 "-A INPUT -m state --state NEW -p tcp --dport 25 -j RETURN"


# Allow incoming NRPE -----------------------------------------
S=""
S="$S 62.50.111.16/28"      # monitor.lf.net
S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 5666 -j RETURN
done

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN


# Allow SSH from known sources ----------------------------------------------------
iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp --dport 22 -j RETURN

# Allow all from LF
iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -j RETURN


# Tue Apr 24 14:32:40 CEST 2018 -Rodney
# - n00.c01.t01.lf.net Service IP
iptables -A $IPT -m state --state NEW -p tcp --dport 5000 -d 62.50.112.240 -j RETURN


# nfs01.t01.lf.net, Zugriff von n00.c01.t01.lf.net aus
iptables -A $IPT -m state --state NEW -s 213.178.160.45 -d 62.50.112.194 -j RETURN
iptables -A $IPT -m state --state NEW -s 212.9.181.127 -d 62.50.112.194 -j RETURN

# nXX.c02.lf.net Zugriff auf nfs01.c01.lf.net
iptables -A $IPT -m state --state NEW -s 62.50.114.64/27 -d 62.50.112.211 -j RETURN -m comment --comment "nXX.c02.lf.net to nfs01.c01.lf.net"


# # ----------------------------------------------------------------------------------------
# # FIXME - POT Staging nach extern offen
# #iptables -A $IPT -m state --state NEW -p tcp --dport 80 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp --dport 9082 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp --dport 81 -d 62.50.112.210 -j RETURN

# # Daimler Proxies auf CWS
# iptables -A $IPT -m state --state NEW -p tcp --dport 80 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp -s 141.113.3.21 --dport 80 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp -s 141.113.3.22 --dport 80 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp -s 141.113.11.21 --dport 80 -d 62.50.112.210 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp -s 141.113.11.22 --dport 80 -d 62.50.112.210 -j RETURN


# # -----------------------------------------------------------------------------------------
# # mvus01.lf.net, Service IP
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp -d 62.50.112.225/32 -j RETURN
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -d 62.50.112.225/32 -j RETURN
# iptables -A $IPT -m state --state NEW -d 62.50.112.225/32 -j REJECT
# 
# # mvus02.lf.net, Service IP (Ryan Allan, mmapi)
# iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.226/32 --dport 80 -j RETURN
# iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.226/32 --dport 443 -j RETURN
# 
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp -d 62.50.112.226/32 -j RETURN
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -d 62.50.112.226/32 -j RETURN
# iptables -A $IPT -m state --state NEW -d 62.50.112.226/32 -j REJECT


# # -----------------------------------------------------------------------------------------
# # mmapi01.us.mvision.lf.net, VM f. Ryan Allen
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp -d 62.50.112.216/32 -j RETURN
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -d 62.50.112.216/32 -j RETURN
# #iptables -A $IPT -m state --state NEW -d 62.50.112.216/32 -j REJECT
# 
# # -----------------------------------------------------------------------------------------
# # mvus03.lf.net, Service IP
# iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.227/32 -j RETURN
# # (ist komplett offen)


# Zugriff auf n00.c05.t01.lf.net ----------------------------------------------------------
#iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -d 62.50.112.232 -j RETURN
#iptables -A $IPT -m state --state NEW -p tcp -s 213.178.160.60 -d 62.50.112.232 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.232 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.233 -j RETURN

iptables -A $IPT -m state --state NEW -p tcp -d 213.178.160.60 --dport 443 -j RETURN -m comment --comment "registry.lf.net"




# # Allow MVISION US Test
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp --dport 80 -j RETURN
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp --dport 8081 -j RETURN
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp --dport 22 -j RETURN
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp --dport 80 -j RETURN
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp --dport 8081 -j RETURN
# iptables -A $IPT -m set --match-set MVISION src -m state --state NEW -p tcp --dport 9082 -j RETURN
# 
# # tftp
# iptables -A $IPT -m set --match-set LF src -m state --state NEW -p udp --dport 69 -d 213.178.160.42 -j RETURN
# 
# iptables -A $IPT -m set --match-set LF src -d 62.50.112.0/27 -j RETURN


# Service IPs fuer n00.c*.t01.lf.net:
iptables -A $IPT -m state --state NEW -d 62.50.112.224/27 -j RETURN
#iptables -A $IPT -m set --match-set LF src -d 62.50.112.224/27 -j RETURN


# Allow Bacula TCP/9102 from backup.lf.net --------------
S=""
S="$S 213.178.160.3/32"
S="$S 213.178.162.248/32"
S="$S 212.9.160.62/32"
S="$S 212.9.160.106/32"
S="$S 212.9.160.135/32"
S="$S 212.9.161.106/32"
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 9102 -j RETURN
done


# Fri Mar 23 23:27:00 CET 2018 -Rodney
# - revproxyNN.lf.net
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.200/32 --match multiport --dports 80,443 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.201/32 --match multiport --dports 80,443 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.202/32 --match multiport --dports 80,443 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.203/32 --match multiport --dports 80,443 -j RETURN

# Tue Sep 22 15:44:54 CEST 2020 -Rodney
# - revproxyNN.lf.net, mehrere Netze f. DDoS Defending
iptables -A $IPT -m state --state NEW -p tcp -d 213.178.180.0/24 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 212.118.190.0/24 -j RETURN

# Fuer Syslog zu log01.lf.net
iptables -A $IPT -m state --state NEW -p udp -d 212.118.190.0/24 -j RETURN

# Mon Sep 19 14:14:24 CEST 2022 -Rodney
# - n00.c02.lf.net Service IPs
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.114.96/28 -j RETURN


# eth1: VLAN 598
#
# FIXME, TODO:
# - wir wollen ausgehenden Traffic "ins Internet" erlauben.
# - wir wollen aber NICHT pauschal den Traffic in alle anderen von uns geschuetzten
#   Netze erlauben!
#
iptables -I $IPT -m state --state NEW -i eth1 -m set \! --match-set KNOWN dst \
                 -m comment --comment "to internet" \
                 -j RETURN

#iptables -I $IPT -m state --state NEW -i eth1 -j RETURN -m comment --comment "Allow outgoing. FIXME, this is too much."

iptables -I $IPT -i eth4 -j RETURN # FIXME, warum?

iptables -I $IPT -m state --state NEW -i eth4 -m set \! --match-set KNOWN dst \
                 -m comment --comment "to internet" \
                 -j RETURN


# Das Netz mit den echten, fixen IPs soll nach draussen koennen:
#iptables -I $IPT -m state --state NEW -p tcp -i eth2 -o eth0 -j RETURN
#iptables -I $IPT -m state --state NEW -p udp -i eth2 -o eth0 -j RETURN

#iptables -I $IPT -i eth2 -p tcp --tcp-flags SYN,ACK,FIN,RST
#iptables -I $IPT -i eth2 -p tcp --tcp-flags RST RST -j RETURN -m comment --comment "Allow RST, to smooth our logging"

iptables -I $IPT -m state --state NEW -i eth2 -m set \! --match-set KNOWN dst \
                 -m comment --comment "to internet" \
                 -j RETURN

# eth5 
#iptables -I $IPT -m state --state NEW -i eth5 -o eth0 -j RETURN
iptables -I $IPT -m state --state NEW -i eth5 -m set \! --match-set KNOWN dst \
                 -m comment --comment "to internet" \
                 -j RETURN

# eth3
#iptables -I $IPT -m state --state NEW -i eth3 -o eth0 -j RETURN
iptables -I $IPT -m state --state NEW -i eth3 -m set \! --match-set KNOWN dst \
                 -m comment --comment "to internet" \
                 -j RETURN


# Optional: Do some logging
#iptables -A $IPT -m state --state INVALID -j LOG --log-prefix "INVALID-"
iptables -A $IPT -m state --state INVALID -j DROP -m comment --comment "Do not log invalid"
#iptables -A $IPT \! -i eth0 -j LOG --log-prefix "DROP-"
iptables -A $IPT -j LOG --log-prefix "DROP-"

# Last rule should always be a DROP!
iptables -A $IPT -j DROP


# NAT =============================================
iptables -t nat -F

# "Von den internen 10.0.0.0/8 Adressen ins Web-LAN, outgoing ueber eth0, SNAT machen"
iptables -t nat -A POSTROUTING -s 10.0.0.0/8 -o eth0 -j SNAT --to-source 62.50.112.224

# IPv6 =======================================================

ip6tables --policy INPUT DROP
ip6tables -F INPUT

ip6tables --policy FORWARD DROP
ip6tables -F FORWARD


# EOF
