#!/bin/bash

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

sysctl -w net.ipv4.netfilter.ip_conntrack_max=500000

# Default is to keep the existing policy untouched.
#iptables --policy INPUT DROP
#iptables --policy FORWARD DROP

# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

# FIXME, geht das eleganter?
while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1

# We want our chain as the first entry.
iptables -I FORWARD -j $IPT-FORWARD

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

# Allow all traffic within a set of networks
MYSET=iptables-autoapply-mynetworks
ipset flush $MYSET
ipset destroy $MYSET

ipset create $MYSET hash:net > /dev/null 2>&1
#ipset add $MYSET 62.50.100.2/27
ipset add $MYSET 10.0.0.0/8
ipset add $MYSET 192.168.0.0/16
ipset add $MYSET 172.16.0.0/16
ipset add $MYSET 127.0.0.0/8

# Allow access within our networks
iptables -A $IPT -m set --match-set $MYSET src,dst -j RETURN


# -------------------------------------------------------
# LF.net trusted networks
ipset flush LF
ipset destroy LF
ipset create LF hash:net > /dev/null 2>&1

ipset add LF 212.9.190.0/24       # LF.net Office
ipset add LF 212.9.190.18/32      # zen.lf.net
ipset add LF 212.9.160.200/32     # outcast.lf.net
ipset add LF 213.178.172.16/32    # volz.eu
ipset add LF 212.9.183.0/25       # LF.net VPN network
ipset add LF 212.9.190.49/32      # hydra3.lf.net
ipset add LF 62.50.111.16/28      # monitor.lf.net
ipset add LF 62.50.100.152/32     # monitor.volz.eu

# ---------------------------
# "List of known networks"
# - Liste der Netze, die wir schuetzen.
# - Liste der Rechner, die bei einem 'allow any' nicht gemeint sind.
# - d.h. zum Beispiel alle die, fuer die wir direkt oder indirekt Gateway sind
#

ipset create KNOWN-CIDR hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1

# - Alle Netze, in denen wir Interfaces haben
# - Aber, nicht eth0, denn das ist das externe IF.
#ip a l | egrep 'inet.*brd.*scope' | while read a b c; do
#  ipset add tmp $b --comment "$a $b $c"
#done

# Ansatz:
# - in der route list stehen alle Netze, die wir kennen.
# - d.h. die ist hinreichend.
ip r l | grep -v default | while read a b; do
  ipset add tmp $a --comment "Route: $a $b"
done

ipset swap tmp KNOWN-CIDR
ipset destroy tmp

ipset l KNOWN-CIDR


# ---
# "Liste der Netze/Rechner, die wir schuetzen"
ipset create KNOWN list:set timeout 0 comment > /dev/null 2>&1
ipset create tmp list:set timeout 0 comment > /dev/null 2>&1

ipset add tmp KNOWN-CIDR --exist --comment "CIDRs we know and protect"
#ipset add tmp MVISION --exist --comment "bla"

ipset swap KNOWN tmp
ipset destroy tmp


# Allow incoming NRPE -----------------------------------------
S=""
S="$S 62.50.111.16/28"      # monitor.lf.net
S="$S 62.50.100.152/32"     # monitor.volz.eu
for i in $S
do
  iptables -A $IPT -s $i -m state --state NEW -p tcp --dport 5666 -j RETURN
done

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN



# Allow SSH from known sources ----------------------------------------------------
iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp --dport 22 -j RETURN

# Allow all from LF
iptables -A $IPT -m set --match-set LF src -m state --state NEW -p tcp -j RETURN


# Fri Mar 23 23:27:00 CET 2018 -Rodney
# - revproxyNN.lf.net
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.200/32 -j RETURN
iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.201/32 -j RETURN

iptables -A $IPT -m state --state NEW -p tcp -d 62.50.112.240/32 -j RETURN

# FIXME: hierdurch geht DHCP, aber es geht zuviel anderes.
iptables -I $IPT -i ens19 -j RETURN
#iptables -I $IPT -i eth4 -j RETURN

## # Das Netz mit den echten, fixen IPs soll nach draussen koennen:
## iptables -I $IPT -m state --state NEW -p tcp -i eth2 -o eth0 -j RETURN
## iptables -I $IPT -m state --state NEW -p udp -i eth2 -o eth0 -j RETURN

# Last rule should always be a DROP!
iptables -A $IPT -j DROP


# NAT =============================================
iptables -t nat -F

# "Von den internen 10.0.0.0/8 Adressen ins Web-LAN, outgoing ueber eth0, SNAT machen"
iptables -t nat -A POSTROUTING -s 10.0.0.0/8 -d 212.9.181.0/24 -o ens20 -j SNAT --to-source 212.9.181.127
iptables -t nat -A POSTROUTING -s 10.0.0.0/8 -o ens18 -j SNAT --to-source 213.178.160.45

# IPv6 =======================================================

ip6tables --policy INPUT DROP
ip6tables -F INPUT

ip6tables --policy FORWARD DROP
ip6tables -F FORWARD


# EOF
