#!/bin/bash

PATH=/sbin:$PATH

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY


# ---------------------------------------------------------
# ipsets


# -----

# TODO/FIXME: Directory f. cidr-lists sollte /usr/share/... sein, mit optionalem /etc/network/iptables-autoapply/cidr-lists als Vorrang.
# Ein temporaeres Set zum Befuellen:
for i in asia russia; do
  ipset create cidr-$i hash:net > /dev/null 2>&1
  ipset create tmp-cidr-$i hash:net maxelem 200000 > /dev/null 2>&1; ipset flush tmp-cidr-$i
  grep -v '^#' /etc/network/iptables-autoapply/cidr-lists/$i.list | while read a; do
    echo "add tmp-cidr-$i $a"
  done | ipset restore

  # Aktiven Block mit dem temporaeren tauschen u. dann temporaeren entfernen:
  ipset swap cidr-$i tmp-cidr-$i
  ipset destroy tmp-cidr-$i
done

set -x

# -----
ipset create black-src hash:net timeout 600 comment > /dev/null 2>&1

# Wird z.B. von RATELIMIT Chain befuellt.


# -----
ipset create black-dst hash:net timeout 600 comment > /dev/null 2>&1
ipset flush black-dst

# ipset add black-dst 212.9.186.40/32 --exist timeout 0 # DDoS 20200928 Caparol
# ipset add black-dst 212.9.186.49/32 --exist timeout 0 # DDoS 20201127, vserv.aki-stuttgart.de


# -----
ipset create black-sets-src list:set timeout 600 comment > /dev/null 2>&1
ipset flush black-sets-src
ipset add black-sets-src black-src --exist timeout 0 # blacklistet source IP, *immer* blocken

# ipset add black-sets-src cidr-russia --exist timeout 0    # NOTFALL: Russia blocken
# ipset add black-sets-src cidr-asia --exist timeout 0      # NOTFALL: Asien blocken (inkl. Russia etc.)



# ----
# Logging mit lists:set (set of sets)

ipset create log hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

# src und dst muessen in dieser Liste sein, damit gelogged wird.
ipset add tmp 185.53.204.230/32 comment "Spirit21"
ipset add tmp 185.53.204.10/32 comment "Spirit21"
ipset add tmp 141.113.36.40/32 comment "Spirit21"
ipset add tmp 212.9.191.0/24
ipset add tmp 212.9.190.0/24

ipset swap tmp log
ipset destroy tmp

ipset create log-sets list:set timeout 0 comment > /dev/null 2>&1
ipset flush log-sets

ipset add log-sets log



# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT
#iptables -A $IPT-FORWARD -m set --match-set log-sets src,dst -j LOG --log-prefix "ALLOW "
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT


# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1
# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT

while iptables -D FORWARD -j $IPT-FORWARD; do echo .; done > /dev/null 2>&1
iptables -I FORWARD -j $IPT-FORWARD

# For safety
iptables -I INPUT -s 212.9.190.0/24 -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "SSH from known sources"
iptables -I INPUT -s 212.9.160.0/24 -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "SSH from LF core backbone"
#iptables -I $IPT -s 212.9.190.0/24 -m state --state NEW -p tcp --dport 22 -j ACCEPT -m comment --comment "SSH from known sources"

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN


# NAT ===============================================================

# Initialize
iptables -t nat -F POSTROUTING
iptables -t nat -F PREROUTING

#iptables -t nat -A POSTROUTING -s 10.0.0.0/8 -o ens18 -j SNAT --to-source 213.178.160.47

# Example for DNAT to bastion host
#iptables -t nat -A PREROUTING -d 62.50.114.16 -p tcp -m tcp --dport 22 -j DNAT --to-destination 10.96.39.11


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

# Allow all from LAN systems
iptables -A $IPT -d 127.0.0.0/8 -j RETURN

# auf loopback alles erlauben
iptables -A $IPT -i lo -j RETURN


#iptables -A $IPT -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
#iptables -A $IPT -m set --match-set black-dst dst -j DROP -m comment --comment "Dynamic dst block"
iptables -A $IPT -m set --match-set white-src src -j RETURN -m comment --comment "Accept from LF white-src"


# ------------
# OSPF in bestimmten Netzen
#iptables -A $IPT -i bond0.100 -s 212.9.160.64/27 -p 89 -j ACCEPT
iptables -A $IPT -s 212.9.160.64/27 --proto 89 -j RETURN -m comment --comment "OSPF mit LF core-Backbone"

# ----------------------------------
# LF.net office Mail services
iptables -A $IPT -s 212.9.190.0/24 -o vlan0166 -j ACCEPT -m comment --comment "$C: Office LAN to mailserver DMZ"
iptables -A $IPT -s 212.9.183.0/25 -o vlan0166 -j ACCEPT -m comment --comment "$C: MA OpenVPN to mailserver DMZ"
# Let's encrypt und Buypass brauchen http-Zugriff auf den revproxy
iptables -A $IPT -o vlan0166 -j ACCEPT -m comment --comment "$C: HTTP to mailserver DMZ"

# ----------------------------------
# DAIMLER BP Connect

C="DAIMLER_BP"
iptables -A $IPT -i vlan0164 -o vlan0100 -j RETURN -m comment --comment "DAIMLER BP WAN1 to LF Backbone"

# Zugriff f. SPIRIT21 auf Fortigate FW
ipset create spirit21 hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

ipset add tmp 185.53.204.230/32 comment "$C: Spirit21"
ipset add tmp 185.53.204.10/32 comment "$C: Spirit21"
ipset add tmp 141.113.36.40/32 comment "$C: Spirit21"

ipset swap tmp spirit21
ipset destroy tmp

iptables -A $IPT -m set --match-set spirit21 src --dst 212.9.191.132 -j RETURN -m comment --comment "$C: Spirit21 auf Fortigate"

#iptables -A $IPT --dst 212.9.191.132 -j RETURN -m comment --comment "DEBUG: alles offen zu Fortigate"

# Wed Mar 29 16:21:21 UTC 2023 -rodney@LF.net
# - temporaere Rules f. tmp01.lf.net
iptables -A $IPT -s 212.9.191.136/29 -o vlan0100 -j RETURN -m comment --comment "TEMPORARY: $C: Allow BP connect DMZ network to extern"
iptables -A $IPT -s 212.9.190.0/24 -o vlan0165 -j RETURN -m comment --comment "TEMPORARY: $C: Office LAN to BP connect DMZ"


# ---------------------------------
C="LF_OFFICE_SERVICES"

iptables -A $IPT -m set --match-set set-dmz-officeservices src -j RETURN -m comment --comment "$C: Outgoing any. FIXME."

iptables -A $IPT -i vlan0166 -o vlan0100 -j RETURN -m comment --comment "$C: Office DMZ outgoing auf Backbone, allow"

# ------------------------
# Last rule must always be a DROP or REJECT!

iptables -A $IPT -m set --match-set log-sets src,dst -j LOG --log-prefix "DROP "

iptables -A $IPT -j DROP

