#!/bin/bash

PATH=/sbin:/usr/sbin:$PATH
export PATH


# ipsets ---------------------------------------------

ipset destroy tmp > /dev/null 2>&1

# sets for ip rate limit
ipset -exist create black hash:net timeout 3600
ipset -exist create white hash:net timeout 0 comment

# sets for blacklist cidr
ipset create cidr-dummy hash:net > /dev/null 2>&1
ipset create tmp hash:net maxelem 200000 > /dev/null 2>&1; 
ipset swap cidr-dummy tmp
ipset destroy tmp

# cidr set of sets
ipset create black-sets-src list:set > /dev/null 2>&1
ipset destroy tmp > /dev/null 2>&1
ipset create tmp list:set
ipset add tmp cidr-dummy
ipset swap black-sets-src tmp
ipset destroy tmp

# --------------------------------------------

iptables -F
iptables -X

iptables -N DROP_LOG

iptables -N DROP_BLACK_SETS
iptables -A DROP_BLACK_SETS -m limit --limit 15/min -j LOG --log-prefix "Black: "
iptables -A DROP_BLACK_SETS -j DROP

iptables -A INPUT -p tcp -m set --match-set black-sets-src src -j DROP_BLACK_SETS

iptables -A INPUT -m conntrack --ctstate ESTABLISHED,RELATED -j ACCEPT

# Whiteliste specific IPs by adding it to ipset "white"
ipset add white 212.9.176.149/32 comment "VVS LAN Hiding NAZ"

# Allow unlimited from ipset "white"
iptables -A INPUT -p tcp -m set --match-set white src -j ACCEPT

# Eval rate an add to ipset "black" and reject all IPs in "black"
# Safe-Delay ist 3600. D.h. wenn es laenger als 3600m sein soll, 
# dann muss weiter oben der Default angepasst werden.

BURST=300
RATE=5
DELAY=120

iptables -A INPUT -p tcp --dport 80 -m conntrack --ctstate NEW \
                   -m hashlimit --hashlimit-name black --hashlimit-mode srcip \
                   --hashlimit-above $RATE/s --hashlimit-burst $BURST \
                   -j SET --add-set black src --timeout $DELAY --exist

iptables -A INPUT -p tcp --dport 443 -m conntrack --ctstate NEW \
                   -m hashlimit --hashlimit-name black --hashlimit-mode srcip \
                   --hashlimit-above $RATE/s --hashlimit-burst $BURST \
                   -j SET --add-set black src --timeout $DELAY --exist

iptables -A INPUT -p tcp -m set --match-set black src -j DROP_LOG

iptables -A DROP_LOG -m limit --limit 5/min -j LOG --log-prefix "Limit Reject: "
iptables -A DROP_LOG -p tcp -j REJECT --reject-with tcp-reset
iptables -A DROP_LOG -j REJECT --reject-with icmp-host-prohibited

# TODO: Warum kein -j DROP? A: weil die Checkpoint die haengenden Verbindungen 
# sonst nicht terminiert.
