#!/bin/bash

PATH=/sbin:/usr/sbin:$PATH

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

#exit 0 # DEBUG

# ------------------------------
# IP-Adressen und Netze von Kunden und Dienstleistern
# ipset add tmp 62.50.124.50 comment "OpenVPN dienstleister@sowieso.de"

ipset create white-src hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

#ipset add tmp 62.50.111.0/24 comment "monitor.lf.net"
#ipset add tmp xx.xx.xx.0/24 comment "Netze fuer <customer> Proxmox"

# LF.net Support Netze, aus ehemaliger MGMTIN chain
ipset add tmp 212.9.190.0/24 comment "LF.net R27 Office"
#ipset add tmp 212.9.160.128/25
#ipset add tmp 212.9.160.64/27
#ipset add tmp 62.50.111.16/28
#ipset add tmp 212.9.160.15/32
#ipset add tmp 213.178.172.0/26

ipset swap tmp white-src
ipset destroy tmp


# Allow all traffic within a set of networks
ipset create mynetworks hash:net timeout 0 comment > /dev/null 2>&1
ipset create tmp hash:net timeout 0 comment > /dev/null 2>&1
ipset flush tmp

ipset add tmp 10.0.0.0/8
ipset add tmp 192.168.0.0/16
ipset add tmp 172.16.0.0/12
ipset add tmp 127.0.0.0/8

ip a l | egrep 'inet.*brd'  | perl -pe 's/^.*inet ([\d\.]+)\/.*$/$1/' | while read a b; do
  ipset add tmp $a
done

ipset swap tmp mynetworks
ipset destroy tmp


# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null                  # New chain
#iptables -N $IPT-FORWARD 2> /dev/null                # New chain
iptables -N $IPT 2> /dev/null                        # New chain

iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT
iptables -A $IPT-INPUT -j RETURN

# NOT IN USE WITH K8S # iptables -F $IPT-FORWARD
# NOT IN USE WITH K8S # iptables -A $IPT-FORWARD -j $IPT
# NOT IN USE WITH K8S # iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

#iptables -A $IPT -j RETURN -m comment --comment "FIXME: ALLOW-ANY-FOR-DEBUGGING" # all open

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1

# Fri Apr  5 09:37:28 UTC 2024 -rodney@LF.net
# - Es scheint bei einem k8s-Setup egal zu sein, an welcher Stelle in der
#   INPUT Chain unsere Rules stehen.
iptables -I INPUT -j $IPT-INPUT

# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN

#iptables -A $IPT -m state -i lo -j RETURN


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN

iptables -A $IPT -m set --match-set mynetworks src,dst -j RETURN -m comment --comment "Internal traffic"

#iptables -A $IPT -m state --state NEW -p tcp --dport 53 -j RETURN -m comment --comment "DNS"
#iptables -A $IPT -m state --state NEW -p udp --dport 53 -j RETURN -m comment --comment "DNS"

# DEBUG: allow all ssh incoming
#iptables -I $IPT -p tcp --dport 22 -j RETURN -m --comment --comment "*** REMOVE THIS RULE!!! ***"

iptables -A $IPT -m set --match-set white-src src -j RETURN -m comment --comment "SSH from known origins"


# Logging ---------------------------

# Log Chain for packets we drop
iptables -N $IPT-LOG-DROP > /dev/null 2>&1
iptables -F $IPT-LOG-DROP
iptables -A $IPT -j $IPT-LOG-DROP

# Do NOT log some traffic
#iptables -A $IPT-LOG-DROP -i eth0 -j RETURN -m comment --comment "Do not log external scans"
iptables -A $IPT-LOG-DROP -i eth0 --match multiport -p tcp \! --dports 80,443 -j RETURN -m comment --comment "Do not log external scans"

#iptables -A $IPT-LOG-DROP -m state --state INVALID -j LOG --log-prefix "INVALID-"
iptables -A $IPT-LOG-DROP -m state --state INVALID -j RETURN -m comment --comment "Do not log invalid"
#iptables -A $IPT-LOG-DROP \! -i eth0 -j LOG --log-prefix "DROP-"
iptables -A $IPT-LOG-DROP -j LOG --log-prefix "DROP-"



# Last rule must always be a DROP --------------------
iptables -A $IPT -j DROP


# IPv6 =======================================================

ip6tables --policy INPUT DROP
ip6tables -F INPUT

ip6tables --policy FORWARD DROP
ip6tables -F FORWARD


# EOF
