#!/bin/bash

set -Eeu -o pipefail

#set -x # DEBUG

function trap_error {
  # trap_cleanup # in case we want to cleanup something
  echo "$0: failed in line $*" >&2
  exit 2
}

trap 'trap_error $LINENO' ERR

PATH=/sbin:$PATH

ipset destroy tmp > /dev/null 2>&1 || true

# Name of chain to use
IPT=IPTABLES-AUTOAPPLY

. /etc/network/iptables.d/custom

# ---------------------------------------------------------
# ipsets

ipset create tmp-log-targets hash:net timeout 0 > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0

# LF CIDRs
if true; then
  ipset add tmp 62.50.96.0/19
  ipset add tmp 212.9.160.0/19
  ipset add tmp 213.178.160.0/19
  ipset add tmp 212.118.160.0/19
  ipset add tmp 185.217.144.0/22
fi

ipset swap tmp-log-targets tmp
ipset destroy tmp

# -----

# TODO/FIXME: Directory f. cidr-lists sollte /usr/share/... sein, mit optionalem /etc/network/iptables-autoapply/cidr-lists als Vorrang.
# Ein temporaeres Set zum Befuellen:
if false; then
for i in asia russia; do
  ipset create cidr-$i hash:net > /dev/null 2>&1 || true
  ipset create tmp hash:net maxelem 200000
  grep -v '^#' /etc/network/iptables-autoapply/cidr-lists/$i.list | while read a; do
    echo "add tmp $a"
  done | ipset restore

  # Aktiven Block mit dem temporaeren tauschen u. dann temporaeren entfernen:
  ipset swap cidr-$i tmp
  ipset destroy tmp
done
fi


# -----
ipset create black-src hash:net timeout 600 comment > /dev/null 2>&1 || true

# Wird z.B. von RATELIMIT Chain befuellt.

# -----
ipset create black-dst hash:net timeout 600 comment > /dev/null 2>&1 || true
ipset flush black-dst

# ipset add black-dst 212.9.186.40/32 --exist timeout 0 # DDoS 20200928 Caparol
# ipset add black-dst 212.9.186.49/32 --exist timeout 0 # DDoS 20201127, vserv.aki-stuttgart.de


# -----
ipset create black-sets-src list:set timeout 600 comment > /dev/null 2>&1 || true
ipset flush black-sets-src
ipset add black-sets-src black-src --exist timeout 0 # blacklistet source IP, *immer* blocken

# ipset add black-sets-src cidr-russia --exist timeout 0    # NOTFALL: Russia blocken
# ipset add black-sets-src cidr-asia --exist timeout 0      # NOTFALL: Asien blocken (inkl. Russia etc.)

# -----
ipset create white-src hash:net timeout 0 comment > /dev/null 2>&1 || true
ipset create tmp hash:net timeout 0 comment
ipset add tmp 62.50.111.0/24  # comment "monitor.lf.net"
ipset add tmp 212.9.190.0/24 comment "LF.net Office"
ipset add tmp 212.9.160.128/25 comment "LF.net Office VDL"
ipset add tmp 62.50.111.16/28 comment "LF Monitoring - TODO: einschraenken"
# ipset add tmp 213.178.172.0/26 comment "LF MA DSL Netze" # wollen wir nicht offen haben
# ipset add tmp 212.9.160.64/27 comment "Core Backbone, VLAN 100" # Warum soll der auf die Proxmox'e zugreifen duerfen?
# ipset add tmp 212.9.160.15/32 comment "service.lf.net" # unnoetig

ipset swap tmp white-src
ipset destroy tmp

## Kunden-IPs, die auf das Proxmox Cluster per SSH, 8006 etc. zugreifen duerfen
ipset create customer-proxmox-access hash:net timeout 0 comment > /dev/null 2>&1 || true

# Menge der Proxmox-Rechner im Cluster
# TODO: diese in z.B. /etc/network/iptables.d/siriusnet.sh pflegen.
#ipset create proxmox-networks hash:net timeout 0 comment > /dev/null 2>&1 || true

# Initialization ----------------------------------------------------------------
iptables -N $IPT-INPUT 2> /dev/null || true
iptables -N $IPT-FORWARD 2> /dev/null || true
iptables -N $IPT 2> /dev/null || true

# TODO: das sollte erst ganz am Ende passieren.
iptables -F $IPT-INPUT
iptables -A $IPT-INPUT -j $IPT -m comment --comment "jump to iptables-autoapply"
iptables -A $IPT-INPUT -j RETURN

iptables -F $IPT-FORWARD
iptables -A $IPT-FORWARD -j $IPT -m comment --comment "jump to iptables-autoapply"
iptables -A $IPT-FORWARD -j RETURN

iptables -F $IPT

# Hook our iptables-autoapply rules to INPUT/OUTPUT/FORWARD ---------------------------------
## iptables --policy INPUT ACCEPT
## iptables --policy OUTPUT ACCEPT
## iptables --policy FORWARD ACCEPT
## 
## iptables -t mangle -F PREROUTING
## iptables -t mangle -F POSTROUTING
## 
## iptables -F INPUT
## iptables -F OUTPUT
## iptables -F INPUT
## 
## 

ip6tables --policy INPUT DROP
ip6tables -F INPUT

## iptables --policy INPUT DENY # TODO

# FIXME, geht das eleganter?
while iptables -D INPUT -j $IPT-INPUT; do echo .; done > /dev/null 2>&1
#iptables -F INPUT

# We want our chain as the first entry.
iptables -I INPUT -j $IPT-INPUT


# Allow all established traffic
iptables -A $IPT -m state --state ESTABLISHED,RELATED -j RETURN -m comment --comment "Allow established"


# Custom rules ================================================================

# Allow ICMP ---------------------------------------------
iptables -A $IPT -p icmp -j RETURN -m comment --comment "Allow ICMP"

# Allow all from LAN systems
#iptables -A $IPT -d 10.0.0.0/8 -j RETURN
iptables -A $IPT -d 127.0.0.0/8 -j RETURN -m comment --comment "Allow local"

# auf loopback alles erlauben
iptables -A $IPT -i lo -j RETURN -m comment --comment "Allow loopback"


# LOGGING
#-N LOGGING
#-A LOGGING -m limit --limit 5/sec -j LOG --log-prefix "SYN-Defender-Dropped: " --log-level 4

iptables -A $IPT -m set --match-set black-sets-src src -j DROP -m comment --comment "Dynamic src block"
iptables -A $IPT -m set --match-set black-dst dst -j DROP -m comment --comment "Dynamic dst block"
iptables -A $IPT -m set --match-set white-src src -j RETURN -m comment --comment "Accept from LF white-src"


# Proxmox interoperability ---------------------------------------------------
#
# https://pve.proxmox.com/wiki/Firewall
#
iptables -A $IPT -p tcp --dport 8006 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox API"
iptables -A $IPT -p tcp --dport 5900:5999 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox VNC"
iptables -A $IPT -p tcp --dport 22 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox SSH"
iptables -A $IPT -p tcp --dport 3128 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox SPICE"
iptables -A $IPT -p udp --dport 5404:5405 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox corosync"
iptables -A $IPT -p tcp --dport 60000:60050 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox live migration"

iptables -A $IPT -p udp --dport 3784 -m set --match-set proxmox-networks src,dst -j RETURN -m comment --comment "Proxmox SDN"

iptables -A $IPT -p tcp -s 10.0.0.0/8 -d 10.0.0.0/8 --match multiport --dports 3300,6789,6800 -j RETURN -m comment --comment "CEPH. TODO: spezifischer machen."

#iptables -A $IPT -p tcp -s 10.0.0.0/8 -d 10.0.0.0/8 --dport 6800 -j RETURN -m comment --comment "Proxmox CEPH. TODO: spezifischer machen."

# Customer access to proxmox
iptables -A $IPT -p tcp --dport 22 -m set --match-set customer-proxmox-access src -j RETURN -m comment --comment "Access for customers"
iptables -A $IPT -p tcp --dport 8006 -m set --match-set customer-proxmox-access src -j RETURN -m comment --comment "GUI access for customers"

#iptables -A $IPT -m set --match-set proxmox-networks src -j LOG --log-prefix "PROXMOX-NETWORKS blocked: "

iptables -A $IPT -m set --match-set tmp-log-targets src,dst -j LOG --log-prefix "IPTABLES-AUTOAPPLY DROP " # DEBUG

#iptables -A $IPT -j LOG --log-prefix "IPTABLES-AUTOAPPLY DROP " # DEBUG, log all

# Last rule must always be a DROP!
iptables -A $IPT -j DROP

echo "$0: success" >&2
